Supported Characteristics and Services¶
This page lists the GATT characteristics and services currently implemented by the library.
!!! note “Auto-Generated”
This page is automatically generated from the runtime registries and the pinned
Bluetooth SIG YAML data by scripts/generate_char_service_list.py.
The list is updated when new characteristics or services are added. See
Adding Characteristics to learn how to contribute
new characteristics.
Coverage Summary¶
The pinned Bluetooth SIG registry currently defines 504 GATT characteristics and 75 GATT services.
Pinned SIG data commit: e4f6570
The library currently implements 504 of 504 characteristics and 75 of 75 services.
Implemented Characteristics¶
The library currently supports 504 implemented GATT characteristics:
Alert Notification¶
Characteristic |
UUID |
Description |
|---|---|---|
Alert Notification Control Point |
|
The Alert Notification Control Point characteristic is used to enable device-specific procedures related to alert notification. |
New Alert |
|
The New Alert characteristic is used to represent the category of the alert, how many new alerts of that category have occurred in a device and brief text information for the last alert. |
Supported New Alert Category |
|
The Supported New Alert Category characteristic is used to represent the category that the server supports for a new alert. |
Supported Unread Alert Category |
|
The Supported Unread Alert Category characteristic is used to represent the category that the server supports for an unread alert. |
Unread Alert Status |
|
The Unread Alert Status characteristic is used to represent the number of unread alerts in the specific category. |
Audio Input Control¶
Characteristic |
UUID |
Description |
|---|---|---|
Audio Input Control Point |
|
|
Audio Input Description |
|
|
Audio Input State |
|
|
Audio Input Status |
|
|
Audio Input Type |
|
|
Gain Settings Attribute |
|
Automation IO¶
Characteristic |
UUID |
Description |
|---|---|---|
Aggregate |
|
|
Analog |
|
|
Digital |
|
Battery¶
Characteristic |
UUID |
Description |
|---|---|---|
Battery Critical Status |
|
The Battery Critical Status characteristic is used to represent that the device will possibly not function as expected due to low energy or service required. |
Battery Energy Status |
|
The Battery Energy Status characteristic is used to represent details about the energy status of the battery. |
Battery Health Information |
|
The Battery Health Information characteristic is used to represent the health of a battery. |
Battery Health Status |
|
The Battery Health Status characteristic is used to represent several aspects of battery health. |
Battery Information |
|
The Battery Information characteristic is used to represent the physical characteristics of a battery in the context of the battery’s connection in a device. |
Battery Level |
|
The Battery Level characteristic is used to represent the charge level of a battery. |
Battery Level Status |
|
The Battery Level Status characteristic is used to represent the power state of a battery, an identifier used to identify the specific battery associated with the data, and the battery level. |
Battery Time Status |
|
The Battery Time Status characteristic is used to represent time estimates for discharging and charging. |
Estimated Service Date |
|
The Estimated Service Date characteristic is used to represent the estimated date when replacement or servicing is required. |
Manufacturer Name String |
|
The Manufacturer Name String characteristic is used to represent the name of the manufacturer of the device. |
Model Number String |
|
The Model Number String characteristic is used to represent the model number assigned by the device vendor. |
Serial Number String |
|
The Serial Number String characteristic is used to represent the serial number for a device. |
Blood Pressure¶
Characteristic |
UUID |
Description |
|---|---|---|
Blood Pressure Feature |
|
The Blood Pressure Feature characteristic is used to represent the supported features of a blood pressure sensor. |
Blood Pressure Measurement |
|
The Blood Pressure Measurement characteristic is used to represent blood pressure measurement data. |
Blood Pressure Record |
|
The Blood Pressure Record characteristic is a container that represents a stored value of a blood pressure measurement or of any other characteristic as specified by the service using the characteristic. |
Enhanced Blood Pressure Measurement |
|
The Enhanced Blood Pressure Measurement characteristic is used to represent data related to a blood pressure measurement that includes a UTC time stamp and a user facing time. |
Enhanced Intermediate Cuff Pressure |
|
The Enhanced Intermediate Cuff Pressure characteristic is used to represent enhanced intermediate Cuff Pressure values for display purposes while a measurement is in progress and includes a UTC time stamp and a user facing time. |
Intermediate Cuff Pressure |
|
The Intermediate Cuff Pressure characteristic is used to send intermediate Cuff Pressure values to a device for display purposes while a measurement is in progress. |
Record Access Control Point |
|
The Record Access Control Point is used to enable service-specific procedures for management of a set of data records. |
Body Composition¶
Characteristic |
UUID |
Description |
|---|---|---|
Body Composition Feature |
|
The Body Composition Feature characteristic is used to represent the supported features of a body composition sensor. |
Body Composition Measurement |
|
The Body Composition Measurement characteristic is used to represent data related to a body composition measurement. |
Bond Management¶
Characteristic |
UUID |
Description |
|---|---|---|
Bond Management Control Point |
|
|
Bond Management Feature |
|
Broadcast Audio Scan¶
Characteristic |
UUID |
Description |
|---|---|---|
Broadcast Audio Scan Control Point |
|
|
Broadcast Receive State |
|
Constant Tone Extension¶
Characteristic |
UUID |
Description |
|---|---|---|
Advertising Constant Tone Extension Interval |
|
|
Advertising Constant Tone Extension Minimum Length |
|
|
Advertising Constant Tone Extension Minimum Transmit Count |
|
|
Advertising Constant Tone Extension Transmit Duration |
|
|
Constant Tone Extension Enable |
|
Continuous Glucose Monitoring¶
Characteristic |
UUID |
Description |
|---|---|---|
Record Access Control Point |
|
The Record Access Control Point is used to enable service-specific procedures for management of a set of data records. |
Cookware¶
Characteristic |
UUID |
Description |
|---|---|---|
Cooking Step Status |
|
The Cooking Step Status characteristic is used to indicate if the cooking step has been started, if the cooking step has been completed, or the time remaining until the completion of the cooking step that is being executed. |
Cooking Zone Actual Cooking Conditions |
|
|
Cooking Zone Capabilities |
|
The Cooking Zone Capabilities characteristic is used to represent the properties of a cooking zone (e.g., a burner of a stove, or a chamber of an oven). |
Cooking Zone Desired Cooking Conditions |
|
|
Cookware Description |
|
|
Cookware Sensor Aggregate |
|
|
Cookware Sensor Data |
|
|
Recipe Control |
|
The Recipe Control characteristic allows clients to manage execution of cooking steps by a cooking appliance. |
Recipe Parameters |
|
The Recipe Parameters characteristic is used to represent the parameters associated with a cooking step that are exchanged between a cooking appliance, a cookware device, and/or a cooking controller for control and monitoring. |
Coordinated Set Identification¶
Characteristic |
UUID |
Description |
|---|---|---|
Coordinated Set Name |
|
|
Coordinated Set Size |
|
|
Set Identity Resolving Key |
|
|
Set Member Lock |
|
|
Set Member Rank |
|
Current Time¶
Characteristic |
UUID |
Description |
|---|---|---|
Current Time |
|
The Current Time characteristic is used to represent the exact time and the reason for adjustment. |
Local Time Information |
|
The Local Time Information characteristic is used to represent the relation (offset) between local time and UTC. |
Reference Time Information |
|
The Reference Time Information characteristic is used to represent information about the reference time source. |
Cycling Power¶
Characteristic |
UUID |
Description |
|---|---|---|
Cycling Power Control Point |
|
The Cycling Power Control Point characteristic is used to enable device-specific procedures related to a cycling power sensor. |
Cycling Power Feature |
|
The Cycling Power Feature characteristic is used to represent the supported features of a cycling power sensor. |
Cycling Power Measurement |
|
The Cycling Power Measurement characteristic is used to represent data related to a cycling power sensor. |
Cycling Power Vector |
|
The Cycling Power Vector characteristic is used to represent power vector data related to a cycling power sensor. |
Sensor Location |
|
The Sensor Location characteristic is used to represent the location of the sensor. |
Cycling Speed and Cadence¶
Characteristic |
UUID |
Description |
|---|---|---|
Sensor Location |
|
The Sensor Location characteristic is used to represent the location of the sensor. |
Device Information¶
Characteristic |
UUID |
Description |
|---|---|---|
Firmware Revision String |
|
The Firmware Revision String characteristic is used to represent the revision of the firmware within the device. |
Hardware Revision String |
|
The Hardware Revision String characteristic is used to represent the hardware revision for the hardware within the device. |
Manufacturer Name String |
|
The Manufacturer Name String characteristic is used to represent the name of the manufacturer of the device. |
Model Number String |
|
The Model Number String characteristic is used to represent the model number assigned by the device vendor. |
Serial Number String |
|
The Serial Number String characteristic is used to represent the serial number for a device. |
Software Revision String |
|
The Software Revision String characteristic is used to represent the revision of the software within the device. |
Device Time¶
Characteristic |
UUID |
Description |
|---|---|---|
Device Time |
|
|
Device Time Control Point |
|
|
Device Time Feature |
|
|
Device Time Parameters |
|
|
Record Access Control Point |
|
The Record Access Control Point is used to enable service-specific procedures for management of a set of data records. |
Time Change Log Data |
|
Elapsed Time¶
Characteristic |
UUID |
Description |
|---|---|---|
Elapsed Time |
|
The Elapsed Time characteristic is used to represent the current time of a clock or tick counter at the time an event occurred. |
Emergency Configuration¶
Characteristic |
UUID |
Description |
|---|---|---|
Emergency Text |
|
Environmental Sensing¶
Characteristic |
UUID |
Description |
|---|---|---|
Ammonia Concentration |
|
The Ammonia Concentration characteristic is used to represent a measure of ammonia (NH3) concentration. |
Apparent Wind Direction |
|
The Apparent Wind Direction characteristic is used to represent the apparent wind direction. |
Apparent Wind Speed |
|
The Apparent Wind Speed characteristic is used to represent the apparent wind speed. |
Barometric Pressure Trend |
|
The Barometric Pressure Trend characteristic is used to represent the trend observed for barometric pressure. |
Carbon Monoxide Concentration |
|
The Carbon Monoxide Concentration characteristic is used to represent a measure of carbon monoxide (CO) concentration. |
Descriptor Value Changed |
|
|
Dew Point |
|
The Dew Point characteristic is used to represent the dew point. |
Elevation |
|
The Elevation characteristic is used to represent the elevation. |
Gust Factor |
|
The Gust Factor characteristic is used to represent the gust factor. |
Heat Index |
|
The Heat Index characteristic is used to represent the heat index. |
Humidity |
|
The Humidity characteristic is used to represent the humidity. |
Irradiance |
|
The Irradiance characteristic is used to represent the irradiance, the radiant flux received by a surface per unit area. |
Magnetic Declination |
|
The Magnetic Declination characteristic is used to represent the magnetic declination. |
Magnetic Flux Density - 2D |
|
The Magnetic Flux Density - 2D characteristic is used to represent measurements of magnetic flux density for two orthogonal axes: X and Y. |
Magnetic Flux Density - 3D |
|
The Magnetic Flux Density - 3D characteristic is used to represent measurements of magnetic flux density for three orthogonal axes: X, Y, and Z. |
Methane Concentration |
|
The Methane Concentration characteristic is used to represent a measure of methane (CH4) concentration. |
Nitrogen Dioxide Concentration |
|
The Nitrogen Dioxide Concentration characteristic is used to represent a measure of nitrogen dioxide (NO2) concentration. |
Non-Methane Volatile Organic Compounds Concentration |
|
The Non-Methane Volatile Organic Compounds Concentration characteristic is used to represent a measure of non-methane volatile organic compounds (NMVOCs) concentration. |
Ozone Concentration |
|
The Ozone Concentration characteristic is used to represent a measure of ozone (O3) concentration. |
Pollen Concentration |
|
The Pollen Concentration characteristic is used to represent the pollen count. |
Pressure |
|
The Pressure characteristic is used to represent pressure. |
Rainfall |
|
The Rainfall characteristic is used to represent the amount of rain that has fallen. |
Sulfur Dioxide Concentration |
|
The Sulfur Dioxide Concentration characteristic is used to represent a measure of sulfur dioxide (SO2) concentration. |
Sulfur Hexafluoride Concentration |
|
The Sulfur Hexafluoride Concentration characteristic is used to represent a measure of sulfur hexafluoride (SF6) concentration. |
Temperature |
|
The Temperature characteristic is used to represent a temperature. |
True Wind Direction |
|
The True Wind Direction characteristic is used to represent the true wind direction. |
True Wind Speed |
|
The True Wind Speed characteristic is used to represent the true wind speed. |
Wind Chill |
|
The Wind Chill characteristic is used to represent the wind chill factor. |
Fitness Machine¶
Characteristic |
UUID |
Description |
|---|---|---|
Cross Trainer Data |
|
The Cross Trainer Data characteristic is used to represent data related to cross trainer activity. |
Fitness Machine Control Point |
|
|
Fitness Machine Feature |
|
|
Fitness Machine Status |
|
|
Indoor Bike Data |
|
The Indoor Bike Data characteristic is used to represent data related to the use of an indoor bike. |
Rower Data |
|
The Rower Data characteristic is used to represent data related to a rowing device. |
Stair Climber Data |
|
The Stair Climber Data characteristic is used to represent data related to a stair climber device. |
Step Climber Data |
|
The Step Climber Data characteristic is used to represent data related to a step climber device. |
Supported Heart Rate Range |
|
The Supported Heart Rate Range characteristic is used to represent the heart rate range supported by a fitness machine. |
Supported Inclination Range |
|
The Supported Inclination Range characteristic is used to represent the inclination range supported by a fitness machine. |
Supported Power Range |
|
The Supported Power Range characteristic is used to represent the power range supported by a fitness machine. |
Supported Resistance Level Range |
|
The Supported Resistance Level Range characteristic is used to represent the resistance level range supported by a fitness machine. |
Supported Speed Range |
|
The Supported Speed Range characteristic is used to represent the speed range supported by a fitness machine. |
Training Status |
|
|
Treadmill Data |
|
The Treadmill Data characteristic is used to represent data related to a treadmill. |
GAP¶
Characteristic |
UUID |
Description |
|---|---|---|
Appearance |
|
|
Device Name |
|
GATT¶
Characteristic |
UUID |
Description |
|---|---|---|
Service Changed |
|
Generic Health Sensor¶
Characteristic |
UUID |
Description |
|---|---|---|
Health Sensor Features |
|
|
Live Health Observations |
|
|
Observation Schedule Changed |
|
|
Record Access Control Point |
|
The Record Access Control Point is used to enable service-specific procedures for management of a set of data records. |
Stored Health Observations |
|
Generic Media Control¶
Characteristic |
UUID |
Description |
|---|---|---|
Media Control Point |
|
|
Media Control Point Opcodes Supported |
|
|
Media Player Name |
|
|
Media State |
|
|
Playback Speed |
|
|
Playing Order |
|
|
Playing Orders Supported |
|
|
Search Control Point |
|
|
Seeking Speed |
|
|
Track Changed |
|
|
Track Duration |
|
|
Track Position |
|
|
Track Title |
|
Generic Telephone Bearer¶
Characteristic |
UUID |
Description |
|---|---|---|
Bearer List Current Calls |
|
|
Bearer Provider Name |
|
|
Bearer Signal Strength |
|
|
Bearer Signal Strength Reporting Interval |
|
|
Bearer Technology |
|
|
Call Control Point |
|
|
Call Friendly Name |
|
|
Call State |
|
|
Incoming Call |
|
|
Status Flags |
|
|
Termination Reason |
|
Generic Voice Assistant¶
Characteristic |
UUID |
Description |
|---|---|---|
Installed Location |
|
|
Voice Assistant Name |
|
|
Voice Assistant Service Control Point |
|
|
Voice Assistant Session Flag |
|
|
Voice Assistant Session State |
|
|
Voice Assistant Supported Features |
|
|
Voice Assistant Supported Languages |
|
Glucose¶
Characteristic |
UUID |
Description |
|---|---|---|
Glucose Feature |
|
The Glucose Feature characteristic is used to represent the supported features of a glucose sensor. |
Glucose Measurement |
|
The Glucose Measurement characteristic is used to represent data related to a glucose measurement record. |
Glucose Measurement Context |
|
The Glucose Measurement Context characteristic is used to represent context information associated with a glucose measurement record. |
Record Access Control Point |
|
The Record Access Control Point is used to enable service-specific procedures for management of a set of data records. |
Health Thermometer¶
Characteristic |
UUID |
Description |
|---|---|---|
Intermediate Temperature |
|
The Intermediate Temperature characteristic is used to send intermediate temperature values to a device for display purposes while a measurement is in progress. |
Measurement Interval |
|
The Measurement Interval characteristic is used to represent the time between measurements. |
Temperature Measurement |
|
The Temperature Measurement characteristic is used to represent data related to a temperature measurement. |
Temperature Type |
|
The Temperature Type characteristic is used to represent the location of a temperature measurement. |
Hearing Access¶
Characteristic |
UUID |
Description |
|---|---|---|
Active Preset Index |
|
|
Hearing Aid Features |
|
|
Hearing Aid Preset Control Point |
|
Heart Rate¶
Characteristic |
UUID |
Description |
|---|---|---|
Body Sensor Location |
|
The Body Sensor Location characteristic is used to represent the location of a sensor on a human body. |
Heart Rate Control Point |
|
The Heart Rate Control Point characteristic is used to enable device-specific procedures related to a heart rate sensor. |
Heart Rate Measurement |
|
The Heart Rate Measurement characteristic is used to represent data related to a heart rate measurement. |
Human Interface Device¶
Characteristic |
UUID |
Description |
|---|---|---|
Boot Keyboard Input Report |
|
|
Boot Keyboard Output Report |
|
|
Boot Mouse Input Report |
|
|
Protocol Mode |
|
|
Report |
|
|
Report Map |
|
Immediate Alert¶
Characteristic |
UUID |
Description |
|---|---|---|
Alert Level |
|
The Alert Level characteristic is used to represent the level of an alert. |
Indoor Positioning¶
Characteristic |
UUID |
Description |
|---|---|---|
Altitude |
|
|
Floor Number |
|
|
Indoor Positioning Configuration |
|
|
Latitude |
|
|
Local East Coordinate |
|
|
Local North Coordinate |
|
|
Location Name |
|
|
Longitude |
|
|
Uncertainty |
|
Industrial Measurement Device¶
Characteristic |
UUID |
Description |
|---|---|---|
Acceleration |
|
The Acceleration characteristic is used to represent the acceleration of an object along a given axis as determined by the service. |
First Use Date |
|
|
Force |
|
The Force characteristic is used to represent the force being applied to an object along a given axis. |
Length |
|
The Length characteristic is used to represent the measured dimension of an object along a given axis. |
Life Cycle Data |
|
|
Linear Position |
|
The Linear Position characteristic is used to represent the linear position of an object along a given axis and referencing to the device-specific zero point. |
Record Access Control Point |
|
The Record Access Control Point is used to enable service-specific procedures for management of a set of data records. |
Rotational Speed |
|
The Rotational Speed characteristic is used to represent the rotational speed of an object rotating around a device-specific axis. |
Service Cycle Data |
|
|
Temperature |
|
The Temperature characteristic is used to represent a temperature. |
Torque |
|
The Torque characteristic is used to represent the measured magnitude of torque (or moment of force) around a device-specific axis. |
Work Cycle Data |
|
Link Loss¶
Characteristic |
UUID |
Description |
|---|---|---|
Alert Level |
|
The Alert Level characteristic is used to represent the level of an alert. |
Media Control¶
Characteristic |
UUID |
Description |
|---|---|---|
Media Control Point |
|
|
Media Control Point Opcodes Supported |
|
|
Media Player Name |
|
|
Media State |
|
|
Playback Speed |
|
|
Playing Order |
|
|
Playing Orders Supported |
|
|
Search Control Point |
|
|
Seeking Speed |
|
|
Track Changed |
|
|
Track Duration |
|
|
Track Position |
|
|
Track Title |
|
Mesh Provisioning¶
Characteristic |
UUID |
Description |
|---|---|---|
Mesh Provisioning Data In |
|
|
Mesh Provisioning Data Out |
|
Mesh Proxy¶
Characteristic |
UUID |
Description |
|---|---|---|
Mesh Proxy Data In |
|
|
Mesh Proxy Data Out |
|
Microphone Control¶
Characteristic |
UUID |
Description |
|---|---|---|
Mute |
|
Object Transfer¶
Characteristic |
UUID |
Description |
|---|---|---|
Object Action Control Point |
|
|
Object Changed |
|
|
Object First-Created |
|
The Object First-Created characteristic is used to represent the date and time when the associated object’s contents were first created. |
Object Last-Modified |
|
The Object Last-Modified characteristic is used to represent the date and time when the associated object’s contents were last modified. |
Object List Control Point |
|
|
Object List Filter |
|
|
Object Name |
|
The Object Name characteristic is used to represent the name of the associated object. |
Object Properties |
|
|
Object Size |
|
|
Object Type |
|
The Object Type characteristic is used to represent the type of the associated object, representing this with a UUID. |
Phone Alert Status¶
Characteristic |
UUID |
Description |
|---|---|---|
Alert Status |
|
The Alert Status characteristic is used to represent the status of a phone alert. |
Ringer Control Point |
|
The Ringer Control Point characteristic is used to enable device-specific procedures for a ringer in a phone. |
Ringer Setting |
|
The Ringer Setting characteristic is used to represent the setting of the ringer. |
Physical Activity Monitor¶
Characteristic |
UUID |
Description |
|---|---|---|
General Activity Instantaneous Data |
|
|
General Activity Summary Data |
|
|
Physical Activity Current Session |
|
|
Physical Activity Monitor Control Point |
|
|
Physical Activity Monitor Features |
|
|
Physical Activity Session Descriptor |
|
|
Sleep Activity Instantaneous Data |
|
|
Sleep Activity Summary Data |
|
|
Step Counter Activity Summary Data |
|
Published Audio Capabilities¶
Characteristic |
UUID |
Description |
|---|---|---|
Available Audio Contexts |
|
|
Sink Audio Locations |
|
|
Source Audio Locations |
|
|
Supported Audio Contexts |
|
Pulse Oximeter¶
Characteristic |
UUID |
Description |
|---|---|---|
Record Access Control Point |
|
The Record Access Control Point is used to enable service-specific procedures for management of a set of data records. |
Ranging¶
Characteristic |
UUID |
Description |
|---|---|---|
Ranging Data Overwritten |
|
|
Ranging Data Ready |
|
Reconnection Configuration¶
Characteristic |
UUID |
Description |
|---|---|---|
Reconnection Configuration Control Point |
|
Reference Time Update¶
Characteristic |
UUID |
Description |
|---|---|---|
Time Update Control Point |
|
The Time Update Control Point characteristic is used to enable device-specific procedures related to a time server. |
Time Update State |
|
The Time Update State characteristic is used to represent the status of the time update process and the result of the last update in a time server. |
Running Speed and Cadence¶
Characteristic |
UUID |
Description |
|---|---|---|
Sensor Location |
|
The Sensor Location characteristic is used to represent the location of the sensor. |
Scan Parameters¶
Characteristic |
UUID |
Description |
|---|---|---|
Scan Interval Window |
|
|
Scan Refresh |
|
Telephone Bearer¶
Characteristic |
UUID |
Description |
|---|---|---|
Bearer List Current Calls |
|
|
Bearer Provider Name |
|
|
Bearer Signal Strength |
|
|
Bearer Signal Strength Reporting Interval |
|
|
Bearer Technology |
|
|
Call Control Point |
|
|
Call Control Point Optional Opcodes |
|
|
Call Friendly Name |
|
|
Call State |
|
|
Incoming Call |
|
|
Status Flags |
|
|
Termination Reason |
|
Tx Power¶
Characteristic |
UUID |
Description |
|---|---|---|
Tx Power Level |
|
The Tx Power Level characteristic is used to represent the current radiated transmit power level. |
User Data¶
Characteristic |
UUID |
Description |
|---|---|---|
Activity Goal |
|
The Activity Goal characteristic is used to represent the goal or target of a user, such as number of steps or total energy expenditure, related to a physical activity session. |
Aerobic Heart Rate Lower Limit |
|
The Aerobic Heart Rate Lower Limit characteristic is used to represent the desired lower limit of the heart rate, where a user enhances his or her endurance while exercising. |
Aerobic Heart Rate Upper Limit |
|
The Aerobic Heart Rate Upper Limit characteristic is used to represent the desired upper limit of the heart rate, where a user enhances his or her endurance while exercising. |
Aerobic Threshold |
|
The Aerobic Threshold characteristic is used to represent the aerobic threshold of a user. |
Age |
|
The Age characteristic is used to represent the age of a user. |
Anaerobic Heart Rate Lower Limit |
|
The Anaerobic Heart Rate Lower Limit characteristic is used to represent the desired lower limit of the heart rate, where a user enhances his or her anaerobic tolerance while exercising. |
Anaerobic Heart Rate Upper Limit |
|
The Anaerobic Heart Rate Upper Limit characteristic is used to represent the desired upper limit of the heart rate, where a user enhances his or her anaerobic tolerance while exercising. |
Anaerobic Threshold |
|
The Anaerobic Threshold characteristic is used to represent the anaerobic threshold of a user. |
Caloric Intake |
|
The Caloric Intake characteristic is used to represent the calorie intake per day of a user. |
Database Change Increment |
|
The Database Change Increment characteristic is used to represent a count of the changes made to a set of related characteristic(s) as defined by the containing service. |
Device Wearing Position |
|
The Device Wearing Position characteristic is used to represent the position where a user is wearing the device. |
Email Address |
|
The Email Address characteristic is used to represent the email address of a user. |
Fat Burn Heart Rate Lower Limit |
|
The Fat Burn Heart Rate Lower Limit characteristic is used to represent the desired lower limit of the heart rate, where a user maximizes the fat burn while exercising. |
Fat Burn Heart Rate Upper Limit |
|
The Fat Burn Heart Rate Upper Limit characteristic is used to represent the desired upper limit of the heart rate, where a user maximizes the fat burn while exercising. |
First Name |
|
The First Name characteristic is used to represent the first name of a user. |
Five Zone Heart Rate Limits |
|
The Five Zone Heart Rate Limits characteristic is used to represent the limits between the heart rate zones for the five-zone heart rate definition (Maximum, Hard, Moderate, Light, and Very Light) of a user. |
Four Zone Heart Rate Limits |
|
The Four Zone Heart Rate Limits characteristic is used to represent the limits between the heart rate zones for the four-zone heart rate definition (Maximum, Hard, Moderate, and Light) of a user. |
Gender |
|
The Gender characteristic is used to represent the gender of a user. |
Handedness |
|
The Handedness characteristic is used to represent the handedness of a user. |
Heart Rate Max |
|
The Heart Rate Max characteristic is used to represent the maximum heart rate of a user which the user intends not to exceed. |
Height |
|
The Height characteristic is used to represent the height of a user. |
High Intensity Exercise Threshold |
|
The High Intensity Exercise Threshold characteristic is used to represent the high intensity exercise threshold of a user. |
High Resolution Height |
|
The High Resolution Height characteristic is used to represent the height of a user and is used when a resolution of 0.1 mm is required. |
Hip Circumference |
|
The Hip Circumference characteristic is used to represent the hip circumference measurement of a user. |
Language |
|
The Language characteristic is used to represent the preferred language of a user. |
Last Name |
|
The Last Name characteristic is used to represent the last name of a user. |
Maximum Recommended Heart Rate |
|
The Maximum Recommended Heart Rate characteristic is used to represent the maximum recommended heart rate of a user. |
Middle Name |
|
The Middle Name characteristic is used to represent the middle name of a user. |
Preferred Units |
|
The Preferred Units characteristic is the list of units the user prefers. |
Registered User |
|
|
Resting Heart Rate |
|
The Resting Heart Rate characteristic is used to represent the resting heart rate of a user. |
Sedentary Interval Notification |
|
The Sedentary Interval Notification characteristic is used to represent the sedentary interval notification of a user. |
Stride Length |
|
The Stride Length characteristic is used to represent the stride length of a user. |
Three Zone Heart Rate Limits |
|
The Three Zone Heart Rate Limits characteristic is used to represent the limits between the heart rate zones for the three-zone heart rate definition (Hard, Moderate, and Light) of a user. |
Two Zone Heart Rate Limits |
|
The Two Zone Heart Rate Limits characteristic is used to represent the heart rate limit between the heart rate zones for the two-zone heart rate definition (Fitness and Fat Burn) of a user. |
User Control Point |
|
|
User Index |
|
The User Index characteristic is used to represent the index of a user. |
Waist Circumference |
|
The Waist Circumference characteristic is used to represent the waist measurement of a user. |
Weight |
|
The Weight characteristic is used to represent the weight of a user. |
Voice Assistant¶
Characteristic |
UUID |
Description |
|---|---|---|
Installed Location |
|
|
Voice Assistant Name |
|
|
Voice Assistant Service Control Point |
|
|
Voice Assistant Session Flag |
|
|
Voice Assistant Session State |
|
|
Voice Assistant Supported Features |
|
|
Voice Assistant Supported Languages |
|
Volume Control¶
Characteristic |
UUID |
Description |
|---|---|---|
Volume Control Point |
|
|
Volume Flags |
|
|
Volume State |
|
Volume Offset Control¶
Characteristic |
UUID |
Description |
|---|---|---|
Audio Location |
|
|
Audio Output Description |
|
|
Volume Offset Control Point |
|
|
Volume Offset State |
|
Weight Scale¶
Characteristic |
UUID |
Description |
|---|---|---|
Weight Measurement |
|
The Weight Measurement characteristic is used to represent data related to a weight measurement. |
Weight Scale Feature |
|
The Weight Scale Feature characteristic is used to represent the supported features of a weight scale. |
Other Characteristics¶
Characteristic |
UUID |
Description |
|---|---|---|
ACS Control Point |
|
|
ACS Data In |
|
|
ACS Data Out Indicate |
|
|
ACS Data Out Notify |
|
|
ACS Status |
|
|
AP Sync Key Material |
|
|
ASE Control Point |
|
|
Acceleration - 3D |
|
The Acceleration - 3D characteristic represents a measure of acceleration with a limited range. |
Acceleration Detection Status |
|
The Acceleration Detection Status characteristic represents the status of detected acceleration. |
Advertising Constant Tone Extension PHY |
|
|
Alert Category ID |
|
The Alert Category ID characteristic is used to represent predefined categories of alerts and messages. |
Alert Category ID Bit Mask |
|
The Alert Category ID Bit Mask characteristic is used to represent support for predefined Category IDs. |
Apparent Energy 32 |
|
The Apparent Energy 32 characteristic is used to represent the integral of Apparent Power over a time interval. |
Apparent Power |
|
The Apparent Power characteristic is used to represent the product of the quadratic mean values of voltage and current. |
Average Current |
|
The Average Current characteristic is used to represent average electric current over a period of time. |
Average Voltage |
|
The Average Voltage characteristic is used to represent average voltage over a period of time. |
BGR Features |
|
|
BGS Features |
|
|
BR-EDR Handover Data |
|
|
BSS Control Point |
|
|
BSS Response |
|
|
Bearer UCI |
|
|
Bearer URI Schemes Supported List |
|
|
Bluetooth SIG Data |
|
|
Boolean |
|
The Boolean characteristic is used to represent the predefined Boolean values. |
CGM Feature |
|
The CGM Feature characteristic is used to represent the supported features of a continuous glucose monitor (CGM). |
CGM Measurement |
|
The CGM Measurement characteristic is used to represent one or more CGM Measurement Records. |
CGM Session Run Time |
|
The CGM Session Run Time characteristic is used to represent the expected run time of the continuous glucose monitor (CGM) session. |
CGM Session Start Time |
|
The CGM Session Start Time characteristic is used to represent the time the continuous glucose monitor (CGM) session is started. |
CGM Specific Ops Control Point |
|
The CGM Specific Ops Control Point characteristic is used to enable procedures related to a continuous glucose monitor (CGM). |
CGM Status |
|
The CGM Status characteristic is used to represent the current status of a continuous glucose monitor (CGM) sensor. |
CIE 13.3-1995 Color Rendering Index |
|
The CIE 13.3-1995 Color Rendering Index characteristic is used to represent a color rendition index value for a color patch as calculated in accordance with the CIE 13.3-1995 standard. |
CO2 Concentration |
|
The CO2 Concentration characteristic is used to represent a measure of carbon dioxide concentration. |
CSC Feature |
|
The CSC Feature characteristic is used to represent the supported features of a cycling speed and cadence (CSC) sensor. |
CSC Measurement |
|
The CSC Measurement characteristic is used to represent data related to a cycling speed and cadence (CSC) sensor. |
CardioRespiratory Activity Instantaneous Data |
|
|
CardioRespiratory Activity Summary Data |
|
|
Central Address Resolution |
|
|
Chromatic Distance from Planckian |
|
The Chromatic Distance from Planckian characteristic is used to represent a distance of a chromaticity coordinate from the Planckian locus in the (u′, 2/3v′) diagram as defined by ANSI standard C78.377-2008 \RefRef{ansi_anslg_c78. |
Chromaticity Coordinate |
|
The Chromaticity Coordinate characteristic is used to represent an x- or y-coordinate in a color diagram such as the CIE1931 diagram \RefRef{cie_1931. |
Chromaticity Coordinates |
|
The Chromaticity Coordinates characteristic is used to represent a chromaticity coordinate. |
Chromaticity Tolerance |
|
The Chromaticity Tolerance characteristic is used to represent the tolerance of a tuple of chromaticity values. |
Chromaticity in CCT and Duv Values |
|
The Chromaticity in CCT and Duv Values characteristic is used to represent the combination of the Correlated Color Temperature characteristic and the Chromatic Distance From Planckian characteristic. |
Client Supported Features |
|
|
Coefficient |
|
The Coefficient characteristic is used to represent a general coefficient value. |
Contact Status 8 |
|
The Contact Status 8 characteristic represents the status of up to 8 binary (open/close) contacts, for instance in a dry contact switch. |
Content Control ID |
|
The Content Control ID (CCID) characteristic is used to represent a unique instance of a service that either controls or provides status information on an audio-related feature. |
Cooking Temperature |
|
The Cooking Temperature characteristic is used to represent a temperature during the cooking process. |
Cooking Zone Perceived Power |
|
The Cooking Zone Perceived Power characteristic is used to represent the percentage of nominal power as perceived by the associated cookware device (i.e., the percentage of the maximum amount of heat that is delivered to the cookware device compared to when nominal power is applied). |
Correlated Color Temperature |
|
The Correlated Color Temperature characteristic is used to represent correlated color temperature. |
Cosine of the Angle |
|
The Cosine of the Angle characteristic represents a value of the cosine of an angle. |
Count 16 |
|
The Count 16 characteristic is used to represent a general count value. |
Count 24 |
|
The Count 24 characteristic is used to represent a general count value. |
Country Code |
|
The Country Code characteristic is used to represent a country or dependent areas in accordance with the ISO 3166-1 Numeric standard \RefRef{iso_3166_1. |
Current Group Object ID |
|
|
Current Track Object ID |
|
|
Current Track Segments Object ID |
|
|
DST Offset |
|
The DST Offset characteristic is used to represent daylight saving time information associated with time. |
Database Hash |
|
|
Date Time |
|
The Date Time characteristic is used to represent date and time. |
Date UTC |
|
The Date UTC characteristic is used to represent the date as days elapsed since the Epoch (Jan 1, 1970) in the Coordinated Universal Time (UTC) time zone. |
Date of Birth |
|
The Date of Birth characteristic is used to represent the date of birth of a user as defined by the Gregorian calendar. |
Date of Threshold Assessment |
|
The Date of Threshold Assessment characteristic is used to represent the date of threshold assessment of a user. |
Day Date Time |
|
The Day Date Time characteristic is used to represent weekday, date, and time. |
Day of Week |
|
The Day of Week characteristic is used to represent the day within a seven-day week as specified in ISO 8601 \RefRef{iso_8601. |
Door/Window Status |
|
The Door/Window Status characteristic represents the status of a door or a window. |
ESL Address |
|
|
ESL Control Point |
|
|
ESL Current Absolute Time |
|
|
ESL Display Information |
|
|
ESL Image Information |
|
|
ESL LED Information |
|
|
ESL Response Key Material |
|
|
ESL Sensor Information |
|
|
Electric Current |
|
The Electric Current characteristic is used to represent an electric current. |
Electric Current Range |
|
The Electric Current Range characteristic is used to represent a range of electric current values. |
Electric Current Specification |
|
The Electric Current Specification characteristic is used to represent a specification of an electric current value. |
Electric Current Statistics |
|
The Electric Current Statistics characteristic is used to represent a set of statistical electric current values. |
Emergency ID |
|
|
Encrypted Data Key Material |
|
|
Energy |
|
The Energy characteristic is used to represent a measure of energy. |
Energy 32 |
|
The Energy 32 characteristic is used to represent a measure of energy. |
Energy in a Period of Day |
|
The Energy in a Period of Day characteristic is used to represent energy use in a period of a day. |
Event Statistics |
|
The Event Statistics characteristic is used to represent statistical values of events. |
Exact Time 256 |
|
The Exact Time 256 characteristic is used to represent the day, date, and time, including fractions of seconds. |
Fixed String 16 |
|
The Fixed String 16 characteristic is used to represent a variable-length UTF-8 string with a maximum length of 16 octets, see Volume 1, Part E, Section 2.9.3 in [1]. |
Fixed String 24 |
|
The Fixed String 24 characteristic is used to represent a variable-length UTF-8 string with a maximum length of 24 octets, see Volume 1, Part E, Section 2.9.3 in [1]. |
Fixed String 36 |
|
The Fixed String 36 characteristic is used to represent a variable-length UTF-8 string with a maximum length of 36 octets, see Volume 1, Part E, Section 2.9.3 in [1]. |
Fixed String 64 |
|
The Fixed String 64 characteristic is used to represent a variable-length UTF-8 string with a maximum length of 64 octets, see Volume 1, Part E, Section 2.9.3 in [1]. |
Fixed String 8 |
|
The Fixed String 8 characteristic is used to represent a variable-length UTF-8 string with a maximum length of 8 octets, see Volume 1, Part E, Section 2.9.3 in [1]. |
GHS Control Point |
|
|
GMAP Role |
|
|
Generic Level |
|
The Generic Level characteristic is used to represent a general level value of a setting of a device. |
Global Trade Item Number |
|
The Global Trade Item Number characteristic is used to represent an identifier as defined by GS1 \RefRef{gs1, with up to 14 digits. |
HID Control Point |
|
|
HID ISO Properties |
|
|
HID Information |
|
|
HTTP Control Point |
|
|
HTTP Entity Body |
|
|
HTTP Headers |
|
|
HTTP Status Code |
|
|
HTTPS Security |
|
|
High Temperature |
|
The High Temperature characteristic is used to represent a temperature within a wide range of possible temperatures. |
High Voltage |
|
The High Voltage characteristic is used to represent a measure of positive electric potential difference. |
Humidity 8 |
|
The Humidity 8 characteristic represents humidity with a limited range. |
IDD Annunciation Status |
|
|
IDD Command Control Point |
|
|
IDD Command Data |
|
|
IDD Features |
|
|
IDD History Data |
|
|
IDD Record Access Control Point |
|
|
IDD Status |
|
|
IDD Status Changed |
|
|
IDD Status Reader Control Point |
|
|
IEEE 11073-20601 Regulatory Certification Data List |
|
The IEEE 11073-20601 Regulatory Certification Data List characteristic is used to represent regulatory and certification information for a product in a list defined in IEEE 11073-20601 \RefRef{ieee_11073_20601. |
IMD Control |
|
|
IMD Historical Data |
|
|
IMD Status |
|
|
IMDS Descriptor Value Changed |
|
|
Illuminance |
|
The Illuminance characteristic is used to represent a measure of illuminance. |
Illuminance 16 |
|
The Illuminance 16 characteristic represents a measure of illuminance with a limited range. |
Incoming Call Target Bearer URI |
|
|
Kitchen Appliance Airflow |
|
The Kitchen Appliance Airflow characteristic is used to represent the amount of airflow supported by a kitchen appliance, such as an oven or a range hood. |
LE GATT Security Levels |
|
|
LE HID Operation Mode |
|
|
LN Control Point |
|
The LN Control Point characteristic is used to enable device-specific procedures related to the exchange of location and navigation (LN) information. |
LN Feature |
|
The LN Feature characteristic is used to represent the supported features of a location and navigation (LN) sensor. |
Light Distribution |
|
The Light Distribution characteristic is used to represent the projected pattern of outdoor light that a fixture disperses onto a surface. |
Light Output |
|
The Light Output characteristic is used to represent a measure of the total quantity of visible light emitted by a source per unit of time. |
Light Source Type |
|
The Light Source Type characteristic is used to represent the means by which a luminaire generates light. |
Location and Speed |
|
The Location and Speed characteristic is used to represent data related to a location and speed sensor. |
Luminous Efficacy |
|
The Luminous Efficacy characteristic is used to represent a measure of luminous efficacy. |
Luminous Energy |
|
The Luminous Energy characteristic is used to represent a measure of luminous energy. |
Luminous Exposure |
|
The Luminous Exposure characteristic is used to represent a measure of luminous exposure. |
Luminous Flux |
|
The Luminous Flux characteristic is used to represent a measure of luminous flux. |
Luminous Flux Range |
|
The Luminous Flux Range characteristic is used to represent a luminous flux range. |
Luminous Intensity |
|
The Luminous Intensity characteristic is used to represent the luminous intensity of a beam of light. |
Mass Flow |
|
The Mass Flow characteristic is used to represent a flow of mass. |
Media Player Icon Object ID |
|
|
Media Player Icon URL |
|
|
Next Track Object ID |
|
|
Noise |
|
The Noise characteristic is used to represent a measure of sound pressure level. |
OTS Feature |
|
|
Object ID |
|
The Object ID characteristic is used to represent an object ID for the associated object. |
On-demand Ranging Data |
|
|
PLX Continuous Measurement |
|
|
PLX Features |
|
|
PLX Spot-Check Measurement |
|
|
Parent Group Object ID |
|
|
Particulate Matter - PM1 Concentration |
|
The Particulate Matter - PM1 Concentration characteristic is used to represent a measure of concentration of particulate matter less than 1 micrometer in diameter. |
Particulate Matter - PM10 Concentration |
|
The Particulate Matter - PM10 Concentration characteristic is used to represent a measure of concentration of particulate matter less than 10 micrometers in diameter. |
Particulate Matter - PM2.5 Concentration |
|
The Particulate Matter - PM2.5 Concentration characteristic is used to represent a measure of concentration of particulate matter less than 2.5 micrometers in diameter. |
Perceived Lightness |
|
The Perceived Lightness characteristic is used to represent the perceived lightness of a light. |
Percentage 8 |
|
The Percentage 8 characteristic is used to represent a percentage. |
Percentage 8 Steps |
|
The Percentage 8 Steps characteristic is used to represent a number of steps between 0% and 100% when configuring a Percentage 8 characteristic value (see sec:org.bluetooth.characteristic.percentage_8). |
Peripheral Preferred Connection Parameters |
|
|
Peripheral Privacy Flag |
|
|
PnP ID |
|
The PnP ID characteristic is used to represent a set of values that are used to create a device ID value that is unique for this device. |
Power |
|
The Power characteristic is used to represent a measure of power. |
Power Specification |
|
The Power Specification characteristic is used to represent a specification of power values. |
Precise Acceleration - 3D |
|
The Precise Acceleration - 3D characteristic represents a measure of acceleration. |
Pushbutton Status 8 |
|
The Pushbutton Status 8 characteristic represents the status of up to 4 pushbuttons. |
RAS Control Point |
|
|
RAS Features |
|
|
RC Feature |
|
|
RC Settings |
|
|
RSC Feature |
|
The RSC Feature characteristic is used to represent the supported features of a running speed and cadence (RSC) sensor. |
RSC Measurement |
|
The RSC Measurement characteristic is used to represent data related to a running speed and cadence (RSC) measurement. |
Real-time Ranging Data |
|
|
Reconnection Address |
|
|
Relative Runtime in a Correlated Color Temperature Range |
|
The Relative Runtime in a Correlated Color Temperature Range characteristic is used to represent a relative runtime in a correlated color temperature range. |
Relative Runtime in a Current Range |
|
The Relative Runtime in a Current Range characteristic is used to represent a relative value in an electric current range. |
Relative Runtime in a Generic Level Range |
|
The Relative Runtime in a Generic Level Range characteristic is used to represent a runtime in a generic level range. |
Relative Value in a Period of Day |
|
The Relative Value in a Period of Day characteristic is used to represent the combination of the Percentage 8 characteristic and two instances of the Time Decihour 8 characteristic. |
Relative Value in a Temperature Range |
|
The Relative Value in a Temperature Range characteristic is used to represent the combination of the Percentage 8 characteristic and two instances of the Temperature characteristic. |
Relative Value in a Voltage Range |
|
The Relative Value in a Voltage Range characteristic is used to represent a relative value in a voltage range. |
Relative Value in an Illuminance Range |
|
The Relative Value in an Illuminance Range characteristic is used to represent a relative value in an illuminance range. |
Resolvable Private Address Only |
|
|
SC Control Point |
|
The SC Control Point characteristic is used to enable device-specific procedures related to a speed and cadence (SC) sensor. |
Search Results Object ID |
|
|
Server Supported Features |
|
|
Sink ASE |
|
|
Sink PAC |
|
|
Source ASE |
|
|
Source PAC |
|
|
Sport Type for Aerobic and Anaerobic Thresholds |
|
The Sport Type for Aerobic and Anaerobic Thresholds characteristic is used to represent the sport type applicable to aerobic and anaerobic thresholds for a user. |
System ID |
|
The System ID characteristic is used to represent an extended unique identifier (EUI) of the system implementing the service that contains this characteristic. |
TDS Control Point |
|
|
TMAP Role |
|
|
Temperature 8 |
|
The Temperature 8 characteristic is used to represent a measure of temperature with a limited range. |
Temperature 8 Statistics |
|
The Temperature 8 Statistics characteristic is used to represent temperature statistics over a period of time. |
Temperature 8 in a Period of Day |
|
The Temperature 8 in a Period of Day characteristic is used to represent a temperature setting over a period of time. |
Temperature Range |
|
The Temperature Range characteristic is used to represent a temperature range. |
Temperature Statistics |
|
The Temperature Statistics characteristic is used to represent temperature statistics over a period of time. |
Time Accuracy |
|
The Time Accuracy characteristic is used to represent the accuracy (drift) of time information compared to a reference time source. |
Time Decihour 8 |
|
The Time Decihour 8 characteristic is used to represent a period of time in tenths of an hour. |
Time Exponential 8 |
|
The Time Exponential 8 characteristic is used to represent a measure of a period of time in seconds. |
Time Hour 24 |
|
The Time Hour 24 characteristic is used to represent a period of time in hours. |
Time Millisecond 24 |
|
The Time Millisecond 24 characteristic is used to represent a period of time with a resolution of 1 millisecond. |
Time Second 16 |
|
The Time Second 16 characteristic is used to represent a period of time with a unit of 1 second. |
Time Second 32 |
|
The Time Second 32 characteristic is used to represent a period of time with a unit of 1 second. |
Time Second 8 |
|
The Time Second 8 characteristic is used to represent a period of time with a unit of 1 second. |
Time Source |
|
The Time Source characteristic is used to represent the type of time source that is used for reference time. |
Time Zone |
|
The Time Zone characteristic is used to represent the time difference in 15-minute increments between local standard time and UTC. |
Time with DST |
|
The Time with DST characteristic is used to represent information about a DST change event. |
UDI for Medical Devices |
|
This characteristic is used to represent a unique identification assigned to a medical device and the controlling and assigning bodies. |
UGG Features |
|
|
UGT Features |
|
|
URI |
|
|
UV Index |
|
The UV Index characteristic is used to represent the UV Index. |
VO2 Max |
|
The VO2 Max characteristic is used to represent the maximal oxygen uptake of a user. |
VOC Concentration |
|
The VOC Concentration characteristic is used to represent a measure of volatile organic compounds concentration. |
Voice Assistant UUID |
|
|
Voltage |
|
The Voltage characteristic is used to represent a measure of positive electric potential difference. |
Voltage Frequency |
|
The Voltage Frequency characteristic is used to represent power supply voltage frequency. |
Voltage Specification |
|
The Voltage Specification characteristic is used to represent a specification of voltage values. |
Voltage Statistics |
|
The Voltage Statistics characteristic is used to represent a set of statistical voltage values over a period of time. |
Volume Flow |
|
The Volume Flow characteristic is used to represent a flow of a general volume such as a volume of material or gas. |
Services¶
The library currently supports 75 GATT services:
Service |
UUID |
Description |
|---|---|---|
Alert Notification |
|
Alert Notification Service implementation. |
Audio Input Control |
|
Audio Input Control Service implementation (0x1843). |
Audio Stream Control |
|
Audio Stream Control Service implementation (0x184E). |
Authorization Control |
|
Authorization Control Service implementation (0x183D). |
Automation IO |
|
Automation IO Service implementation. |
Basic Audio Announcement |
|
Basic Audio Announcement Service implementation (0x1851). |
Battery |
|
Battery Service implementation. |
Binary Sensor |
|
Binary Sensor Service implementation (0x183B). |
Blood Pressure |
|
Blood Pressure Service implementation. |
Body Composition |
|
Body Composition Service implementation (0x181B). |
Bond Management |
|
Bond Management Service implementation. |
Broadcast Audio Announcement |
|
Broadcast Audio Announcement Service implementation (0x1852). |
Broadcast Audio Scan |
|
Broadcast Audio Scan Service implementation (0x184F). |
Common Audio |
|
Common Audio Service implementation (0x1853). |
Constant Tone Extension |
|
Constant Tone Extension Service implementation (0x184A). |
Continuous Glucose Monitoring |
|
Continuous Glucose Monitoring Service implementation (0x181F). |
Cookware |
|
Cookware Service implementation (0x185D). |
Coordinated Set Identification |
|
Coordinated Set Identification Service implementation (0x1846). |
Current Time |
|
Current Time Service implementation. |
Cycling Power |
|
Cycling Power Service implementation (0x1818). |
Cycling Speed and Cadence |
|
Cycling Speed and Cadence Service implementation (0x1816). |
Device Information |
|
Device Information Service implementation. |
Device Time |
|
Device Time Service implementation (0x1847). |
Elapsed Time |
|
Elapsed Time Service implementation (0x183F). |
Electronic Shelf Label |
|
Electronic Shelf Label Service implementation (0x1857). |
Emergency Configuration |
|
Emergency Configuration Service implementation (0x183C). |
Environmental Sensing |
|
Environmental Sensing Service implementation (0x181A). |
Fitness Machine |
|
Fitness Machine Service implementation. |
GAP |
|
Generic Access Service implementation. |
GATT |
|
Generic Attribute Service implementation. |
Gaming Audio |
|
Gaming Audio Service implementation (0x1858). |
Generic Health Sensor |
|
Generic Health Sensor Service implementation (0x1840). |
Generic Media Control |
|
Generic Media Control Service implementation (0x1849). |
Generic Telephone Bearer |
|
Generic Telephone Bearer Service implementation (0x184C). |
Generic Voice Assistant |
|
Generic Voice Assistant Service implementation (0x185F). |
Glucose |
|
Glucose Service implementation (0x1808). |
HID ISO |
|
HID ISO Service implementation (0x185C). |
HTTP Proxy |
|
HTTP Proxy Service implementation (0x1823). |
Health Thermometer |
|
Health Thermometer Service implementation (0x1809). |
Hearing Access |
|
Hearing Access Service implementation (0x1854). |
Heart Rate |
|
Heart Rate Service implementation (0x180D). |
Human Interface Device |
|
Human Interface Device Service implementation. |
Immediate Alert |
|
Immediate Alert Service implementation. |
Indoor Positioning |
|
Indoor Positioning Service implementation. |
Industrial Measurement Device |
|
Industrial Measurement Device Service implementation (0x185A). |
Insulin Delivery |
|
Insulin Delivery Service implementation (0x183A). |
Internet Protocol Support |
|
Internet Protocol Support Service implementation (0x1820). |
Link Loss |
|
Link Loss Service implementation. |
Location and Navigation |
|
Location and Navigation Service implementation. |
Media Control |
|
Media Control Service implementation (0x1848). |
Mesh Provisioning |
|
Mesh Provisioning Service implementation (0x1827). |
Mesh Proxy |
|
Mesh Proxy Service implementation (0x1828). |
Mesh Proxy Solicitation |
|
Mesh Proxy Solicitation Service implementation (0x1859). |
Microphone Control |
|
Microphone Control Service implementation (0x184D). |
Next DST Change |
|
Next DST Change Service implementation. |
Object Transfer |
|
Object Transfer Service implementation (0x1825). |
Phone Alert Status |
|
Phone Alert Status Service implementation. |
Physical Activity Monitor |
|
Physical Activity Monitor Service implementation (0x183E). |
Public Broadcast Announcement |
|
Public Broadcast Announcement Service implementation (0x1856). |
Published Audio Capabilities |
|
Published Audio Capabilities Service implementation (0x1850). |
Pulse Oximeter |
|
Pulse Oximeter Service implementation. |
Ranging |
|
Ranging Service implementation (0x185B). |
Reconnection Configuration |
|
Reconnection Configuration Service implementation (0x1829). |
Reference Time Update |
|
Reference Time Update Service implementation. |
Running Speed and Cadence |
|
Running Speed and Cadence Service implementation (0x1814). |
Scan Parameters |
|
Scan Parameters service implementation. |
Telephone Bearer |
|
Telephone Bearer Service implementation (0x184B). |
Telephony and Media Audio |
|
Telephony and Media Audio Service implementation (0x1855). |
Transport Discovery |
|
Transport Discovery Service implementation (0x1824). |
Tx Power |
|
Tx Power Service implementation. |
User Data |
|
User Data Service implementation. |
Voice Assistant |
|
Voice Assistant Service implementation (0x185E). |
Volume Control |
|
Volume Control Service implementation (0x1844). |
Volume Offset Control |
|
Volume Offset Control Service implementation (0x1845). |
Weight Scale |
|
Weight Scale Service implementation (0x181D). |
Adding Support for New Characteristics¶
To add support for a new characteristic:
See the Adding Characteristics guide
Follow the existing patterns in
src/bluetooth_sig/gatt/characteristics/Add tests for your new characteristic in
tests/gatt/characteristics/Submit a pull request
Official Bluetooth SIG Registry¶
This library is based on the official Bluetooth SIG Assigned Numbers
registry. The UUID registry is loaded from YAML files in the bluetooth_sig submodule.