Supported Characteristics and Services

This page lists all GATT characteristics and services currently supported by the library.

!!! note “Auto-Generated” This page is automatically generated from the codebase by scripts/generate_char_service_list.py. The list is updated when new characteristics or services are added. See Adding Characteristics to learn how to contribute new characteristics.

Characteristics

The library currently supports 294 GATT characteristics:

Alert Notification

Characteristic

UUID

Description

Alert Notification Control Point

00002A44-0000-1000-8000-00805F9B34FB

The Alert Notification Control Point characteristic is used to enable device-specific procedures related to alert notification.

New Alert

00002A46-0000-1000-8000-00805F9B34FB

The New Alert characteristic is used to represent the category of the alert, how many new alerts of that category have occurred in a device and brief text information for the last alert.

Supported New Alert Category

00002A47-0000-1000-8000-00805F9B34FB

The Supported New Alert Category characteristic is used to represent the category that the server supports for a new alert.

Supported Unread Alert Category

00002A48-0000-1000-8000-00805F9B34FB

The Supported Unread Alert Category characteristic is used to represent the category that the server supports for an unread alert.

Unread Alert Status

00002A45-0000-1000-8000-00805F9B34FB

The Unread Alert Status characteristic is used to represent the number of unread alerts in the specific category.

Automation IO

Characteristic

UUID

Description

Average Current

00002AE0-0000-1000-8000-00805F9B34FB

The Average Current characteristic is used to represent average electric current over a period of time.

Average Voltage

00002AE1-0000-1000-8000-00805F9B34FB

The Average Voltage characteristic is used to represent average voltage over a period of time.

Electric Current

00002AEE-0000-1000-8000-00805F9B34FB

The Electric Current characteristic is used to represent an electric current.

Voltage

00002B18-0000-1000-8000-00805F9B34FB

The Voltage characteristic is used to represent a measure of positive electric potential difference.

Battery

Characteristic

UUID

Description

Battery Level

00002A19-0000-1000-8000-00805F9B34FB

The Battery Level characteristic is used to represent the charge level of a battery.

Battery Level Status

00002BED-0000-1000-8000-00805F9B34FB

The Battery Level Status characteristic is used to represent the power state of a battery, an identifier used to identify the specific battery associated with the data, and the battery level.

Blood Pressure

Characteristic

UUID

Description

Blood Pressure Feature

00002A49-0000-1000-8000-00805F9B34FB

The Blood Pressure Feature characteristic is used to represent the supported features of a blood pressure sensor.

Blood Pressure Measurement

00002A35-0000-1000-8000-00805F9B34FB

The Blood Pressure Measurement characteristic is used to represent blood pressure measurement data.

Intermediate Cuff Pressure

00002A36-0000-1000-8000-00805F9B34FB

The Intermediate Cuff Pressure characteristic is used to send intermediate Cuff Pressure values to a device for display purposes while a measurement is in progress.

Body Composition

Characteristic

UUID

Description

Body Composition Feature

00002A9B-0000-1000-8000-00805F9B34FB

The Body Composition Feature characteristic is used to represent the supported features of a body composition sensor.

Body Composition Measurement

00002A9C-0000-1000-8000-00805F9B34FB

The Body Composition Measurement characteristic is used to represent data related to a body composition measurement.

Bond Management

Characteristic

UUID

Description

Bond Management Control Point

00002AA4-0000-1000-8000-00805F9B34FB

Bond Management Feature

00002AA5-0000-1000-8000-00805F9B34FB

Current Time

Characteristic

UUID

Description

Current Time

00002A2B-0000-1000-8000-00805F9B34FB

The Current Time characteristic is used to represent the exact time and the reason for adjustment.

Local Time Information

00002A0F-0000-1000-8000-00805F9B34FB

The Local Time Information characteristic is used to represent the relation (offset) between local time and UTC.

Reference Time Information

00002A14-0000-1000-8000-00805F9B34FB

The Reference Time Information characteristic is used to represent information about the reference time source.

Cycling Power

Characteristic

UUID

Description

Cycling Power Control Point

00002A66-0000-1000-8000-00805F9B34FB

The Cycling Power Control Point characteristic is used to enable device-specific procedures related to a cycling power sensor.

Cycling Power Feature

00002A65-0000-1000-8000-00805F9B34FB

The Cycling Power Feature characteristic is used to represent the supported features of a cycling power sensor.

Cycling Power Measurement

00002A63-0000-1000-8000-00805F9B34FB

The Cycling Power Measurement characteristic is used to represent data related to a cycling power sensor.

Cycling Power Vector

00002A64-0000-1000-8000-00805F9B34FB

The Cycling Power Vector characteristic is used to represent power vector data related to a cycling power sensor.

Device Information

Characteristic

UUID

Description

Firmware Revision String

00002A26-0000-1000-8000-00805F9B34FB

The Firmware Revision String characteristic is used to represent the revision of the firmware within the device.

Hardware Revision String

00002A27-0000-1000-8000-00805F9B34FB

The Hardware Revision String characteristic is used to represent the hardware revision for the hardware within the device.

Manufacturer Name String

00002A29-0000-1000-8000-00805F9B34FB

The Manufacturer Name String characteristic is used to represent the name of the manufacturer of the device.

Model Number String

00002A24-0000-1000-8000-00805F9B34FB

The Model Number String characteristic is used to represent the model number assigned by the device vendor.

Serial Number String

00002A25-0000-1000-8000-00805F9B34FB

The Serial Number String characteristic is used to represent the serial number for a device.

Software Revision String

00002A28-0000-1000-8000-00805F9B34FB

The Software Revision String characteristic is used to represent the revision of the software within the device.

Environmental Sensing

Characteristic

UUID

Description

Ammonia Concentration

00002BCF-0000-1000-8000-00805F9B34FB

The Ammonia Concentration characteristic is used to represent a measure of ammonia (NH₃) concentration.

Apparent Wind Direction

00002A73-0000-1000-8000-00805F9B34FB

The Apparent Wind Direction characteristic is used to represent the apparent wind direction.

Apparent Wind Speed

00002A72-0000-1000-8000-00805F9B34FB

The Apparent Wind Speed characteristic is used to represent the apparent wind speed.

Barometric Pressure Trend

00002AA3-0000-1000-8000-00805F9B34FB

The Barometric Pressure Trend characteristic is used to represent the trend observed for barometric pressure.

Dew Point

00002A7B-0000-1000-8000-00805F9B34FB

The Dew Point characteristic is used to represent the dew point.

Elevation

00002A6C-0000-1000-8000-00805F9B34FB

The Elevation characteristic is used to represent the elevation.

Heat Index

00002A7A-0000-1000-8000-00805F9B34FB

The Heat Index characteristic is used to represent the heat index.

Humidity

00002A6F-0000-1000-8000-00805F9B34FB

The Humidity characteristic is used to represent the humidity.

Methane Concentration

00002BD1-0000-1000-8000-00805F9B34FB

The Methane Concentration characteristic is used to represent a measure of methane (CH4) concentration.

Nitrogen Dioxide Concentration

00002BD2-0000-1000-8000-00805F9B34FB

The Nitrogen Dioxide Concentration characteristic is used to represent a measure of nitrogen dioxide (NO₂) concentration.

Non-Methane Volatile Organic Compounds Concentration

00002BD3-0000-1000-8000-00805F9B34FB

The Non-Methane Volatile Organic Compounds Concentration characteristic is used to represent a measure of non-methane volatile organic compounds (NMVOCs) concentration.

Ozone Concentration

00002BD4-0000-1000-8000-00805F9B34FB

The Ozone Concentration characteristic is used to represent a measure of ozone (O₃) concentration.

Pollen Concentration

00002A75-0000-1000-8000-00805F9B34FB

The Pollen Concentration characteristic is used to represent the pollen count.

Pressure

00002A6D-0000-1000-8000-00805F9B34FB

The Pressure characteristic is used to represent pressure.

Rainfall

00002A78-0000-1000-8000-00805F9B34FB

The Rainfall characteristic is used to represent the amount of rain that has fallen.

Sulfur Dioxide Concentration

00002BD8-0000-1000-8000-00805F9B34FB

The Sulfur Dioxide Concentration characteristic is used to represent a measure of sulfur dioxide (SO₂) concentration.

Temperature

00002A6E-0000-1000-8000-00805F9B34FB

The Temperature characteristic is used to represent a temperature.

True Wind Direction

00002A71-0000-1000-8000-00805F9B34FB

The True Wind Direction characteristic is used to represent the true wind direction.

True Wind Speed

00002A70-0000-1000-8000-00805F9B34FB

The True Wind Speed characteristic is used to represent the true wind speed.

Wind Chill

00002A79-0000-1000-8000-00805F9B34FB

The Wind Chill characteristic is used to represent the wind chill factor.

Fitness Machine

Characteristic

UUID

Description

Cross Trainer Data

00002ACE-0000-1000-8000-00805F9B34FB

The Cross Trainer Data characteristic is used to represent data related to cross trainer activity.

Indoor Bike Data

00002AD2-0000-1000-8000-00805F9B34FB

The Indoor Bike Data characteristic is used to represent data related to the use of an indoor bike.

Rower Data

00002AD1-0000-1000-8000-00805F9B34FB

The Rower Data characteristic is used to represent data related to a rowing device.

Stair Climber Data

00002AD0-0000-1000-8000-00805F9B34FB

The Stair Climber Data characteristic is used to represent data related to a stair climber device.

Step Climber Data

00002ACF-0000-1000-8000-00805F9B34FB

The Step Climber Data characteristic is used to represent data related to a step climber device.

Supported Heart Rate Range

00002AD7-0000-1000-8000-00805F9B34FB

The Supported Heart Rate Range characteristic is used to represent the heart rate range supported by a fitness machine.

Supported Inclination Range

00002AD5-0000-1000-8000-00805F9B34FB

The Supported Inclination Range characteristic is used to represent the inclination range supported by a fitness machine.

Supported Power Range

00002AD8-0000-1000-8000-00805F9B34FB

The Supported Power Range characteristic is used to represent the power range supported by a fitness machine.

Supported Resistance Level Range

00002AD6-0000-1000-8000-00805F9B34FB

The Supported Resistance Level Range characteristic is used to represent the resistance level range supported by a fitness machine.

Supported Speed Range

00002AD4-0000-1000-8000-00805F9B34FB

The Supported Speed Range characteristic is used to represent the speed range supported by a fitness machine.

Treadmill Data

00002ACD-0000-1000-8000-00805F9B34FB

The Treadmill Data characteristic is used to represent data related to a treadmill.

GAP

Characteristic

UUID

Description

Appearance

00002A01-0000-1000-8000-00805F9B34FB

Device Name

00002A00-0000-1000-8000-00805F9B34FB

GATT

Characteristic

UUID

Description

Service Changed

00002A05-0000-1000-8000-00805F9B34FB

Glucose

Characteristic

UUID

Description

Glucose Feature

00002A51-0000-1000-8000-00805F9B34FB

The Glucose Feature characteristic is used to represent the supported features of a glucose sensor.

Glucose Measurement

00002A18-0000-1000-8000-00805F9B34FB

The Glucose Measurement characteristic is used to represent data related to a glucose measurement record.

Glucose Measurement Context

00002A34-0000-1000-8000-00805F9B34FB

The Glucose Measurement Context characteristic is used to represent context information associated with a glucose measurement record.

Health Thermometer

Characteristic

UUID

Description

Temperature Measurement

00002A1C-0000-1000-8000-00805F9B34FB

The Temperature Measurement characteristic is used to represent data related to a temperature measurement.

Heart Rate

Characteristic

UUID

Description

Heart Rate Measurement

00002A37-0000-1000-8000-00805F9B34FB

The Heart Rate Measurement characteristic is used to represent data related to a heart rate measurement.

Human Interface Device

Characteristic

UUID

Description

Protocol Mode

00002A4E-0000-1000-8000-00805F9B34FB

Report

00002A4D-0000-1000-8000-00805F9B34FB

Report Map

00002A4B-0000-1000-8000-00805F9B34FB

Immediate Alert

Characteristic

UUID

Description

Alert Level

00002A06-0000-1000-8000-00805F9B34FB

The Alert Level characteristic is used to represent the level of an alert.

Indoor Positioning

Characteristic

UUID

Description

Altitude

00002AB3-0000-1000-8000-00805F9B34FB

Floor Number

00002AB2-0000-1000-8000-00805F9B34FB

Indoor Positioning Configuration

00002AAD-0000-1000-8000-00805F9B34FB

Latitude

00002AAE-0000-1000-8000-00805F9B34FB

Local East Coordinate

00002AB1-0000-1000-8000-00805F9B34FB

Local North Coordinate

00002AB0-0000-1000-8000-00805F9B34FB

Location Name

00002AB5-0000-1000-8000-00805F9B34FB

Longitude

00002AAF-0000-1000-8000-00805F9B34FB

Uncertainty

00002AB4-0000-1000-8000-00805F9B34FB

Location and Navigation

Characteristic

UUID

Description

Navigation

00002A68-0000-1000-8000-00805F9B34FB

The Navigation characteristic is used to represent data related to a navigation sensor.

Position Quality

00002A69-0000-1000-8000-00805F9B34FB

The Position Quality characteristic is used to represent data related to the quality of a position measurement.

Phone Alert Status

Characteristic

UUID

Description

Alert Status

00002A3F-0000-1000-8000-00805F9B34FB

The Alert Status characteristic is used to represent the status of a phone alert.

Ringer Control Point

00002A40-0000-1000-8000-00805F9B34FB

The Ringer Control Point characteristic is used to enable device-specific procedures for a ringer in a phone.

Ringer Setting

00002A41-0000-1000-8000-00805F9B34FB

The Ringer Setting characteristic is used to represent the setting of the ringer.

Reference Time Update

Characteristic

UUID

Description

Time Update Control Point

00002A16-0000-1000-8000-00805F9B34FB

The Time Update Control Point characteristic is used to enable device-specific procedures related to a time server.

Time Update State

00002A17-0000-1000-8000-00805F9B34FB

The Time Update State characteristic is used to represent the status of the time update process and the result of the last update in a time server.

Scan Parameters

Characteristic

UUID

Description

Scan Interval Window

00002A4F-0000-1000-8000-00805F9B34FB

Tx Power

Characteristic

UUID

Description

Tx Power Level

00002A07-0000-1000-8000-00805F9B34FB

The Tx Power Level characteristic is used to represent the current radiated transmit power level.

User Data

Characteristic

UUID

Description

Activity Goal

00002B4E-0000-1000-8000-00805F9B34FB

The Activity Goal characteristic is used to represent the goal or target of a user, such as number of steps or total energy expenditure, related to a physical activity session.

Aerobic Heart Rate Lower Limit

00002A7E-0000-1000-8000-00805F9B34FB

The Aerobic Heart Rate Lower Limit characteristic is used to represent the desired lower limit of the heart rate, where a user enhances his or her endurance while exercising.

Aerobic Heart Rate Upper Limit

00002A84-0000-1000-8000-00805F9B34FB

The Aerobic Heart Rate Upper Limit characteristic is used to represent the desired upper limit of the heart rate, where a user enhances his or her endurance while exercising.

Aerobic Threshold

00002A7F-0000-1000-8000-00805F9B34FB

The Aerobic Threshold characteristic is used to represent the aerobic threshold of a user.

Age

00002A80-0000-1000-8000-00805F9B34FB

The Age characteristic is used to represent the age of a user.

Anaerobic Heart Rate Lower Limit

00002A81-0000-1000-8000-00805F9B34FB

The Anaerobic Heart Rate Lower Limit characteristic is used to represent the desired lower limit of the heart rate, where a user enhances his or her anaerobic tolerance while exercising.

Anaerobic Heart Rate Upper Limit

00002A82-0000-1000-8000-00805F9B34FB

The Anaerobic Heart Rate Upper Limit characteristic is used to represent the desired upper limit of the heart rate, where a user enhances his or her anaerobic tolerance while exercising.

Anaerobic Threshold

00002A83-0000-1000-8000-00805F9B34FB

The Anaerobic Threshold characteristic is used to represent the anaerobic threshold of a user.

Caloric Intake

00002B50-0000-1000-8000-00805F9B34FB

The Caloric Intake characteristic is used to represent the calorie intake per day of a user.

Device Wearing Position

00002B4B-0000-1000-8000-00805F9B34FB

The Device Wearing Position characteristic is used to represent the position where a user is wearing the device.

Email Address

00002A87-0000-1000-8000-00805F9B34FB

The Email Address characteristic is used to represent the email address of a user.

Fat Burn Heart Rate Lower Limit

00002A88-0000-1000-8000-00805F9B34FB

The Fat Burn Heart Rate Lower Limit characteristic is used to represent the desired lower limit of the heart rate, where a user maximizes the fat burn while exercising.

Fat Burn Heart Rate Upper Limit

00002A89-0000-1000-8000-00805F9B34FB

The Fat Burn Heart Rate Upper Limit characteristic is used to represent the desired upper limit of the heart rate, where a user maximizes the fat burn while exercising.

First Name

00002A8A-0000-1000-8000-00805F9B34FB

The First Name characteristic is used to represent the first name of a user.

Five Zone Heart Rate Limits

00002A8B-0000-1000-8000-00805F9B34FB

The Five Zone Heart Rate Limits characteristic is used to represent the limits between the heart rate zones for the five-zone heart rate definition (Maximum, Hard, Moderate, Light, and Very Light) of a user.

Four Zone Heart Rate Limits

00002B4C-0000-1000-8000-00805F9B34FB

The Four Zone Heart Rate Limits characteristic is used to represent the limits between the heart rate zones for the four-zone heart rate definition (Maximum, Hard, Moderate, and Light) of a user.

Gender

00002A8C-0000-1000-8000-00805F9B34FB

The Gender characteristic is used to represent the gender of a user.

Handedness

00002B4A-0000-1000-8000-00805F9B34FB

The Handedness characteristic is used to represent the handedness of a user.

Heart Rate Max

00002A8D-0000-1000-8000-00805F9B34FB

The Heart Rate Max characteristic is used to represent the maximum heart rate of a user which the user intends not to exceed.

Height

00002A8E-0000-1000-8000-00805F9B34FB

The Height characteristic is used to represent the height of a user.

High Intensity Exercise Threshold

00002B4D-0000-1000-8000-00805F9B34FB

The High Intensity Exercise Threshold characteristic is used to represent the high intensity exercise threshold of a user.

High Resolution Height

00002B47-0000-1000-8000-00805F9B34FB

The High Resolution Height characteristic is used to represent the height of a user and is used when a resolution of 0.1 mm is required.

Hip Circumference

00002A8F-0000-1000-8000-00805F9B34FB

The Hip Circumference characteristic is used to represent the hip circumference measurement of a user.

Language

00002AA2-0000-1000-8000-00805F9B34FB

The Language characteristic is used to represent the preferred language of a user.

Last Name

00002A90-0000-1000-8000-00805F9B34FB

The Last Name characteristic is used to represent the last name of a user.

Maximum Recommended Heart Rate

00002A91-0000-1000-8000-00805F9B34FB

The Maximum Recommended Heart Rate characteristic is used to represent the maximum recommended heart rate of a user.

Middle Name

00002B48-0000-1000-8000-00805F9B34FB

The Middle Name characteristic is used to represent the middle name of a user.

Preferred Units

00002B46-0000-1000-8000-00805F9B34FB

The Preferred Units characteristic is the list of units the user prefers.

Resting Heart Rate

00002A92-0000-1000-8000-00805F9B34FB

The Resting Heart Rate characteristic is used to represent the resting heart rate of a user.

Sedentary Interval Notification

00002B4F-0000-1000-8000-00805F9B34FB

The Sedentary Interval Notification characteristic is used to represent the sedentary interval notification of a user.

Stride Length

00002B49-0000-1000-8000-00805F9B34FB

The Stride Length characteristic is used to represent the stride length of a user.

Three Zone Heart Rate Limits

00002A94-0000-1000-8000-00805F9B34FB

The Three Zone Heart Rate Limits characteristic is used to represent the limits between the heart rate zones for the three-zone heart rate definition (Hard, Moderate, and Light) of a user.

Two Zone Heart Rate Limits

00002A95-0000-1000-8000-00805F9B34FB

The Two Zone Heart Rate Limits characteristic is used to represent the heart rate limit between the heart rate zones for the two-zone heart rate definition (Fitness and Fat Burn) of a user.

Waist Circumference

00002A97-0000-1000-8000-00805F9B34FB

The Waist Circumference characteristic is used to represent the waist measurement of a user.

Weight

00002A98-0000-1000-8000-00805F9B34FB

The Weight characteristic is used to represent the weight of a user.

Weight Scale

Characteristic

UUID

Description

Weight Measurement

00002A9D-0000-1000-8000-00805F9B34FB

The Weight Measurement characteristic is used to represent data related to a weight measurement.

Weight Scale Feature

00002A9E-0000-1000-8000-00805F9B34FB

The Weight Scale Feature characteristic is used to represent the supported features of a weight scale.

Other Characteristics

Characteristic

UUID

Description

Acceleration

00002C06-0000-1000-8000-00805F9B34FB

The Acceleration characteristic is used to represent the acceleration of an object along a given axis as determined by the service.

Acceleration 3D

00002C1D-0000-1000-8000-00805F9B34FB

The Acceleration - 3D characteristic represents a measure of acceleration with a limited range.

Acceleration Detection Status

00002C1F-0000-1000-8000-00805F9B34FB

The Acceleration Detection Status characteristic represents the status of detected acceleration.

Alert Category ID

00002A43-0000-1000-8000-00805F9B34FB

The Alert Category ID characteristic is used to represent predefined categories of alerts and messages.

Alert Category ID Bit Mask

00002A42-0000-1000-8000-00805F9B34FB

The Alert Category ID Bit Mask characteristic is used to represent support for predefined Category IDs.

Apparent Energy 32

00002B89-0000-1000-8000-00805F9B34FB

The Apparent Energy 32 characteristic is used to represent the integral of Apparent Power over a time interval.

Apparent Power

00002B8A-0000-1000-8000-00805F9B34FB

The Apparent Power characteristic is used to represent the product of the quadratic mean values of voltage and current.

Battery Critical Status

00002BE9-0000-1000-8000-00805F9B34FB

The Battery Critical Status characteristic is used to represent that the device will possibly not function as expected due to low energy or service required.

Battery Energy Status

00002BF0-0000-1000-8000-00805F9B34FB

The Battery Energy Status characteristic is used to represent details about the energy status of the battery.

Battery Health Information

00002BEB-0000-1000-8000-00805F9B34FB

The Battery Health Information characteristic is used to represent the health of a battery.

Battery Health Status

00002BEA-0000-1000-8000-00805F9B34FB

The Battery Health Status characteristic is used to represent several aspects of battery health.

Battery Information

00002BEC-0000-1000-8000-00805F9B34FB

The Battery Information characteristic is used to represent the physical characteristics of a battery in the context of the battery’s connection in a device.

Battery Time Status

00002BEE-0000-1000-8000-00805F9B34FB

The Battery Time Status characteristic is used to represent time estimates for discharging and charging.

Blood Pressure Record

00002B36-0000-1000-8000-00805F9B34FB

The Blood Pressure Record characteristic is a container that represents a stored value of a blood pressure measurement or of any other characteristic as specified by the service using the characteristic.

Body Sensor Location

00002A38-0000-1000-8000-00805F9B34FB

The Body Sensor Location characteristic is used to represent the location of a sensor on a human body.

Boolean

00002AE2-0000-1000-8000-00805F9B34FB

The Boolean characteristic is used to represent the predefined Boolean values.

Boot Keyboard Input Report

00002A22-0000-1000-8000-00805F9B34FB

Boot Keyboard Output Report

00002A32-0000-1000-8000-00805F9B34FB

Boot Mouse Input Report

00002A33-0000-1000-8000-00805F9B34FB

CGM Feature

00002AA8-0000-1000-8000-00805F9B34FB

The CGM Feature characteristic is used to represent the supported features of a continuous glucose monitor (CGM).

CGM Measurement

00002AA7-0000-1000-8000-00805F9B34FB

The CGM Measurement characteristic is used to represent one or more CGM Measurement Records.

CGM Session Run Time

00002AAB-0000-1000-8000-00805F9B34FB

The CGM Session Run Time characteristic is used to represent the expected run time of the continuous glucose monitor (CGM) session.

CGM Session Start Time

00002AAA-0000-1000-8000-00805F9B34FB

The CGM Session Start Time characteristic is used to represent the time the continuous glucose monitor (CGM) session is started.

CGM Status

00002AA9-0000-1000-8000-00805F9B34FB

The CGM Status characteristic is used to represent the current status of a continuous glucose monitor (CGM) sensor.

CIE 13.3-1995 Color Rendering Index

00002AE7-0000-1000-8000-00805F9B34FB

The CIE 13.3-1995 Color Rendering Index characteristic is used to represent a color rendition index value for a color patch as calculated in accordance with the CIE 13.3-1995 standard.

CO₂ Concentration

00002B8C-0000-1000-8000-00805F9B34FB

The CO₂ Concentration characteristic is used to represent a measure of carbon dioxide concentration.

CSC Feature

00002A5C-0000-1000-8000-00805F9B34FB

The CSC Feature characteristic is used to represent the supported features of a cycling speed and cadence (CSC) sensor.

CSC Measurement

00002A5B-0000-1000-8000-00805F9B34FB

The CSC Measurement characteristic is used to represent data related to a cycling speed and cadence (CSC) sensor.

Carbon Monoxide Concentration

00002BD0-0000-1000-8000-00805F9B34FB

The Carbon Monoxide Concentration characteristic is used to represent a measure of carbon monoxide (CO) concentration.

Chromatic Distance from Planckian

00002AE3-0000-1000-8000-00805F9B34FB

The Chromatic Distance from Planckian characteristic is used to represent a distance of a chromaticity coordinate from the Planckian locus in the (u′, 2/3v′) diagram as defined by ANSI standard C78.377-2008 \RefRef{ansi_anslg_c78.

Chromaticity Coordinate

00002B1C-0000-1000-8000-00805F9B34FB

The Chromaticity Coordinate characteristic is used to represent an x- or y-coordinate in a color diagram such as the CIE1931 diagram \RefRef{cie_1931.

Chromaticity Coordinates

00002AE4-0000-1000-8000-00805F9B34FB

The Chromaticity Coordinates characteristic is used to represent a chromaticity coordinate.

Chromaticity Tolerance

00002AE6-0000-1000-8000-00805F9B34FB

The Chromaticity Tolerance characteristic is used to represent the tolerance of a tuple of chromaticity values.

Chromaticity in CCT and Duv Values

00002AE5-0000-1000-8000-00805F9B34FB

The Chromaticity in CCT and Duv Values characteristic is used to represent the combination of the Correlated Color Temperature characteristic and the Chromatic Distance From Planckian characteristic.

Coefficient

00002AE8-0000-1000-8000-00805F9B34FB

The Coefficient characteristic is used to represent a general coefficient value.

Contact Status 8

00002C22-0000-1000-8000-00805F9B34FB

The Contact Status 8 characteristic represents the status of up to 8 binary (open/close) contacts, for instance in a dry contact switch.

Content Control ID

00002BBA-0000-1000-8000-00805F9B34FB

The Content Control ID (CCID) characteristic is used to represent a unique instance of a service that either controls or provides status information on an audio-related feature.

Correlated Color Temperature

00002AE9-0000-1000-8000-00805F9B34FB

The Correlated Color Temperature characteristic is used to represent correlated color temperature.

Cosine of the Angle

00002B8D-0000-1000-8000-00805F9B34FB

The Cosine of the Angle characteristic represents a value of the cosine of an angle.

Count 16

00002AEA-0000-1000-8000-00805F9B34FB

The Count 16 characteristic is used to represent a general count value.

Count 24

00002AEB-0000-1000-8000-00805F9B34FB

The Count 24 characteristic is used to represent a general count value.

Country Code

00002AEC-0000-1000-8000-00805F9B34FB

The Country Code characteristic is used to represent a country or dependent areas in accordance with the ISO 3166-1 Numeric standard \RefRef{iso_3166_1.

Current Elapsed Time

00002BF2-0000-1000-8000-00805F9B34FB

DST Offset

00002A0D-0000-1000-8000-00805F9B34FB

The DST Offset characteristic is used to represent daylight saving time information associated with time.

Database Change Increment

00002A99-0000-1000-8000-00805F9B34FB

The Database Change Increment characteristic is used to represent a count of the changes made to a set of related characteristic(s) as defined by the containing service.

Date Time

00002A08-0000-1000-8000-00805F9B34FB

The Date Time characteristic is used to represent date and time.

Date UTC

00002AED-0000-1000-8000-00805F9B34FB

The Date UTC characteristic is used to represent the date as days elapsed since the Epoch (Jan 1, 1970) in the Coordinated Universal Time (UTC) time zone.

Date of Birth

00002A85-0000-1000-8000-00805F9B34FB

The Date of Birth characteristic is used to represent the date of birth of a user as defined by the Gregorian calendar.

Date of Threshold Assessment

00002A86-0000-1000-8000-00805F9B34FB

The Date of Threshold Assessment characteristic is used to represent the date of threshold assessment of a user.

Day Date Time

00002A0A-0000-1000-8000-00805F9B34FB

The Day Date Time characteristic is used to represent weekday, date, and time.

Day of Week

00002A09-0000-1000-8000-00805F9B34FB

The Day of Week characteristic is used to represent the day within a seven-day week as specified in ISO 8601 \RefRef{iso_8601.

Door/Window Status

00002C20-0000-1000-8000-00805F9B34FB

The Door/Window Status characteristic represents the status of a door or a window.

Electric Current Range

00002AEF-0000-1000-8000-00805F9B34FB

The Electric Current Range characteristic is used to represent a range of electric current values.

Electric Current Specification

00002AF0-0000-1000-8000-00805F9B34FB

The Electric Current Specification characteristic is used to represent a specification of an electric current value.

Electric Current Statistics

00002AF1-0000-1000-8000-00805F9B34FB

The Electric Current Statistics characteristic is used to represent a set of statistical electric current values.

Energy

00002AF2-0000-1000-8000-00805F9B34FB

The Energy characteristic is used to represent a measure of energy.

Energy 32

00002BA8-0000-1000-8000-00805F9B34FB

The Energy 32 characteristic is used to represent a measure of energy.

Energy in a Period of Day

00002AF3-0000-1000-8000-00805F9B34FB

The Energy in a Period of Day characteristic is used to represent energy use in a period of a day.

Enhanced Blood Pressure Measurement

00002B34-0000-1000-8000-00805F9B34FB

The Enhanced Blood Pressure Measurement characteristic is used to represent data related to a blood pressure measurement that includes a UTC time stamp and a user facing time.

Enhanced Intermediate Cuff Pressure

00002B35-0000-1000-8000-00805F9B34FB

The Enhanced Intermediate Cuff Pressure characteristic is used to represent enhanced intermediate Cuff Pressure values for display purposes while a measurement is in progress and includes a UTC time stamp and a user facing time.

Estimated Service Date

00002BEF-0000-1000-8000-00805F9B34FB

The Estimated Service Date characteristic is used to represent the estimated date when replacement or servicing is required.

Event Statistics

00002AF4-0000-1000-8000-00805F9B34FB

The Event Statistics characteristic is used to represent statistical values of events.

Exact Time 256

00002A0C-0000-1000-8000-00805F9B34FB

The Exact Time 256 characteristic is used to represent the day, date, and time, including fractions of seconds.

Fixed String 16

00002AF5-0000-1000-8000-00805F9B34FB

The Fixed String 16 characteristic is used to represent a variable-length UTF-8 string with a maximum length of 16 octets, see Volume 1, Part E, Section 2.9.3 in [1].

Fixed String 24

00002AF6-0000-1000-8000-00805F9B34FB

The Fixed String 24 characteristic is used to represent a variable-length UTF-8 string with a maximum length of 24 octets, see Volume 1, Part E, Section 2.9.3 in [1].

Fixed String 36

00002AF7-0000-1000-8000-00805F9B34FB

The Fixed String 36 characteristic is used to represent a variable-length UTF-8 string with a maximum length of 36 octets, see Volume 1, Part E, Section 2.9.3 in [1].

Fixed String 64

00002BDE-0000-1000-8000-00805F9B34FB

The Fixed String 64 characteristic is used to represent a variable-length UTF-8 string with a maximum length of 64 octets, see Volume 1, Part E, Section 2.9.3 in [1].

Fixed String 8

00002AF8-0000-1000-8000-00805F9B34FB

The Fixed String 8 characteristic is used to represent a variable-length UTF-8 string with a maximum length of 8 octets, see Volume 1, Part E, Section 2.9.3 in [1].

Force

00002C07-0000-1000-8000-00805F9B34FB

The Force characteristic is used to represent the force being applied to an object along a given axis.

Generic Level

00002AF9-0000-1000-8000-00805F9B34FB

The Generic Level characteristic is used to represent a general level value of a setting of a device.

Global Trade Item Number

00002AFA-0000-1000-8000-00805F9B34FB

The Global Trade Item Number characteristic is used to represent an identifier as defined by GS1 \RefRef{gs1, with up to 14 digits.

Gust Factor

00002A74-0000-1000-8000-00805F9B34FB

The Gust Factor characteristic is used to represent the gust factor.

HID Control Point

00002A4C-0000-1000-8000-00805F9B34FB

HID Information

00002A4A-0000-1000-8000-00805F9B34FB

Heart Rate Control Point

00002A39-0000-1000-8000-00805F9B34FB

The Heart Rate Control Point characteristic is used to enable device-specific procedures related to a heart rate sensor.

High Temperature

00002BDF-0000-1000-8000-00805F9B34FB

The High Temperature characteristic is used to represent a temperature within a wide range of possible temperatures.

High Voltage

00002BE0-0000-1000-8000-00805F9B34FB

The High Voltage characteristic is used to represent a measure of positive electric potential difference.

Humidity 8

00002C1B-0000-1000-8000-00805F9B34FB

The Humidity 8 characteristic represents humidity with a limited range.

IEEE 11073-20601 Regulatory Certification Data List

00002A2A-0000-1000-8000-00805F9B34FB

The IEEE 11073-20601 Regulatory Certification Data List characteristic is used to represent regulatory and certification information for a product in a list defined in IEEE 11073-20601 \RefRef{ieee_11073_20601.

Illuminance

00002AFB-0000-1000-8000-00805F9B34FB

The Illuminance characteristic is used to represent a measure of illuminance.

Illuminance 16

00002C1C-0000-1000-8000-00805F9B34FB

The Illuminance 16 characteristic represents a measure of illuminance with a limited range.

Intermediate Temperature

00002A1E-0000-1000-8000-00805F9B34FB

The Intermediate Temperature characteristic is used to send intermediate temperature values to a device for display purposes while a measurement is in progress.

Irradiance

00002A77-0000-1000-8000-00805F9B34FB

The Irradiance characteristic is used to represent the irradiance, the radiant flux received by a surface per unit area.

LN Control Point

00002A6B-0000-1000-8000-00805F9B34FB

The LN Control Point characteristic is used to enable device-specific procedures related to the exchange of location and navigation (LN) information.

LN Feature

00002A6A-0000-1000-8000-00805F9B34FB

The LN Feature characteristic is used to represent the supported features of a location and navigation (LN) sensor.

Light Distribution

00002BE1-0000-1000-8000-00805F9B34FB

The Light Distribution characteristic is used to represent the projected pattern of outdoor light that a fixture disperses onto a surface.

Light Output

00002BE2-0000-1000-8000-00805F9B34FB

The Light Output characteristic is used to represent a measure of the total quantity of visible light emitted by a source per unit of time.

Light Source Type

00002BE3-0000-1000-8000-00805F9B34FB

The Light Source Type characteristic is used to represent the means by which a luminaire generates light.

Linear Position

00002C08-0000-1000-8000-00805F9B34FB

The Linear Position characteristic is used to represent the linear position of an object along a given axis and referencing to the device-specific zero point.

Location and Speed

00002A67-0000-1000-8000-00805F9B34FB

The Location and Speed characteristic is used to represent data related to a location and speed sensor.

Luminous Efficacy

00002AFC-0000-1000-8000-00805F9B34FB

The Luminous Efficacy characteristic is used to represent a measure of luminous efficacy.

Luminous Energy

00002AFD-0000-1000-8000-00805F9B34FB

The Luminous Energy characteristic is used to represent a measure of luminous energy.

Luminous Exposure

00002AFE-0000-1000-8000-00805F9B34FB

The Luminous Exposure characteristic is used to represent a measure of luminous exposure.

Luminous Flux

00002AFF-0000-1000-8000-00805F9B34FB

The Luminous Flux characteristic is used to represent a measure of luminous flux.

Luminous Flux Range

00002B00-0000-1000-8000-00805F9B34FB

The Luminous Flux Range characteristic is used to represent a luminous flux range.

Luminous Intensity

00002B01-0000-1000-8000-00805F9B34FB

The Luminous Intensity characteristic is used to represent the luminous intensity of a beam of light.

Magnetic Declination

00002A2C-0000-1000-8000-00805F9B34FB

The Magnetic Declination characteristic is used to represent the magnetic declination.

Magnetic Flux Density - 2D

00002AA0-0000-1000-8000-00805F9B34FB

The Magnetic Flux Density - 2D characteristic is used to represent measurements of magnetic flux density for two orthogonal axes: X and Y.

Magnetic Flux Density - 3D

00002AA1-0000-1000-8000-00805F9B34FB

The Magnetic Flux Density - 3D characteristic is used to represent measurements of magnetic flux density for three orthogonal axes: X, Y, and Z.

Mass Flow

00002B02-0000-1000-8000-00805F9B34FB

The Mass Flow characteristic is used to represent a flow of mass.

Measurement Interval

00002A21-0000-1000-8000-00805F9B34FB

The Measurement Interval characteristic is used to represent the time between measurements.

Noise

00002BE4-0000-1000-8000-00805F9B34FB

The Noise characteristic is used to represent a measure of sound pressure level.

Object First-Created

00002AC1-0000-1000-8000-00805F9B34FB

The Object First-Created characteristic is used to represent the date and time when the associated object’s contents were first created.

Object ID

00002AC3-0000-1000-8000-00805F9B34FB

The Object ID characteristic is used to represent an object ID for the associated object.

Object Last-Modified

00002AC2-0000-1000-8000-00805F9B34FB

The Object Last-Modified characteristic is used to represent the date and time when the associated object’s contents were last modified.

Object Name

00002ABE-0000-1000-8000-00805F9B34FB

The Object Name characteristic is used to represent the name of the associated object.

Object Type

00002ABF-0000-1000-8000-00805F9B34FB

The Object Type characteristic is used to represent the type of the associated object, representing this with a UUID.

PLX Continuous Measurement

00002A5F-0000-1000-8000-00805F9B34FB

PLX Features

00002A60-0000-1000-8000-00805F9B34FB

PLX Spot-Check Measurement

00002A5E-0000-1000-8000-00805F9B34FB

Particulate Matter - PM1 Concentration

00002BD5-0000-1000-8000-00805F9B34FB

The Particulate Matter - PM1 Concentration characteristic is used to represent a measure of concentration of particulate matter less than 1 micrometer in diameter.

Particulate Matter - PM10 Concentration

00002BD7-0000-1000-8000-00805F9B34FB

The Particulate Matter - PM10 Concentration characteristic is used to represent a measure of concentration of particulate matter less than 10 micrometers in diameter.

Particulate Matter - PM2.5 Concentration

00002BD6-0000-1000-8000-00805F9B34FB

The Particulate Matter - PM2.5 Concentration characteristic is used to represent a measure of concentration of particulate matter less than 2.5 micrometers in diameter.

Perceived Lightness

00002B03-0000-1000-8000-00805F9B34FB

The Perceived Lightness characteristic is used to represent the perceived lightness of a light.

Percentage 8

00002B04-0000-1000-8000-00805F9B34FB

The Percentage 8 characteristic is used to represent a percentage.

Percentage 8 Steps

00002C05-0000-1000-8000-00805F9B34FB

The Percentage 8 Steps characteristic is used to represent a number of steps between 0% and 100% when configuring a Percentage 8 characteristic value (see sec:org.bluetooth.characteristic.percentage_8).

Peripheral Preferred Connection Parameters

00002A04-0000-1000-8000-00805F9B34FB

Peripheral Privacy Flag

00002A02-0000-1000-8000-00805F9B34FB

PnP ID

00002A50-0000-1000-8000-00805F9B34FB

The PnP ID characteristic is used to represent a set of values that are used to create a device ID value that is unique for this device.

Power

00002B05-0000-1000-8000-00805F9B34FB

The Power characteristic is used to represent a measure of power.

Power Specification

00002B06-0000-1000-8000-00805F9B34FB

The Power Specification characteristic is used to represent a specification of power values.

Precise Acceleration 3D

00002C1E-0000-1000-8000-00805F9B34FB

The Precise Acceleration - 3D characteristic represents a measure of acceleration.

Pushbutton Status 8

00002C21-0000-1000-8000-00805F9B34FB

The Pushbutton Status 8 characteristic represents the status of up to 4 pushbuttons.

RSC Feature

00002A54-0000-1000-8000-00805F9B34FB

The RSC Feature characteristic is used to represent the supported features of a running speed and cadence (RSC) sensor.

RSC Measurement

00002A53-0000-1000-8000-00805F9B34FB

The RSC Measurement characteristic is used to represent data related to a running speed and cadence (RSC) measurement.

Reconnection Address

00002A03-0000-1000-8000-00805F9B34FB

Relative Runtime in a Correlated Color Temperature Range

00002BE5-0000-1000-8000-00805F9B34FB

The Relative Runtime in a Correlated Color Temperature Range characteristic is used to represent a relative runtime in a correlated color temperature range.

Relative Runtime in a Current Range

00002B07-0000-1000-8000-00805F9B34FB

The Relative Runtime in a Current Range characteristic is used to represent a relative value in an electric current range.

Relative Runtime in a Generic Level Range

00002B08-0000-1000-8000-00805F9B34FB

The Relative Runtime in a Generic Level Range characteristic is used to represent a runtime in a generic level range.

Relative Value in a Period of Day

00002B0B-0000-1000-8000-00805F9B34FB

The Relative Value in a Period of Day characteristic is used to represent the combination of the Percentage 8 characteristic and two instances of the Time Decihour 8 characteristic.

Relative Value in a Temperature Range

00002B0C-0000-1000-8000-00805F9B34FB

The Relative Value in a Temperature Range characteristic is used to represent the combination of the Percentage 8 characteristic and two instances of the Temperature characteristic.

Relative Value in a Voltage Range

00002B09-0000-1000-8000-00805F9B34FB

The Relative Value in a Voltage Range characteristic is used to represent a relative value in a voltage range.

Relative Value in an Illuminance Range

00002B0A-0000-1000-8000-00805F9B34FB

The Relative Value in an Illuminance Range characteristic is used to represent a relative value in an illuminance range.

Rotational Speed

00002C09-0000-1000-8000-00805F9B34FB

The Rotational Speed characteristic is used to represent the rotational speed of an object rotating around a device-specific axis.

Scan Refresh

00002A31-0000-1000-8000-00805F9B34FB

Sensor Location

00002A5D-0000-1000-8000-00805F9B34FB

The Sensor Location characteristic is used to represent the location of the sensor.

Sport Type for Aerobic and Anaerobic Thresholds

00002A93-0000-1000-8000-00805F9B34FB

The Sport Type for Aerobic and Anaerobic Thresholds characteristic is used to represent the sport type applicable to aerobic and anaerobic thresholds for a user.

Sulfur Hexafluoride Concentration

00002BD9-0000-1000-8000-00805F9B34FB

The Sulfur Hexafluoride Concentration characteristic is used to represent a measure of sulfur hexafluoride (SF6) concentration.

System ID

00002A23-0000-1000-8000-00805F9B34FB

The System ID characteristic is used to represent an extended unique identifier (EUI) of the system implementing the service that contains this characteristic.

Temperature 8

00002B0D-0000-1000-8000-00805F9B34FB

The Temperature 8 characteristic is used to represent a measure of temperature with a limited range.

Temperature 8 Statistics

00002B0F-0000-1000-8000-00805F9B34FB

The Temperature 8 Statistics characteristic is used to represent temperature statistics over a period of time.

Temperature 8 in a Period of Day

00002B0E-0000-1000-8000-00805F9B34FB

The Temperature 8 in a Period of Day characteristic is used to represent a temperature setting over a period of time.

Temperature Range

00002B10-0000-1000-8000-00805F9B34FB

The Temperature Range characteristic is used to represent a temperature range.

Temperature Statistics

00002B11-0000-1000-8000-00805F9B34FB

The Temperature Statistics characteristic is used to represent temperature statistics over a period of time.

Temperature Type

00002A1D-0000-1000-8000-00805F9B34FB

The Temperature Type characteristic is used to represent the location of a temperature measurement.

Time Accuracy

00002A12-0000-1000-8000-00805F9B34FB

The Time Accuracy characteristic is used to represent the accuracy (drift) of time information compared to a reference time source.

Time Decihour 8

00002B12-0000-1000-8000-00805F9B34FB

The Time Decihour 8 characteristic is used to represent a period of time in tenths of an hour.

Time Exponential 8

00002B13-0000-1000-8000-00805F9B34FB

The Time Exponential 8 characteristic is used to represent a measure of a period of time in seconds.

Time Hour 24

00002B14-0000-1000-8000-00805F9B34FB

The Time Hour 24 characteristic is used to represent a period of time in hours.

Time Millisecond 24

00002B15-0000-1000-8000-00805F9B34FB

The Time Millisecond 24 characteristic is used to represent a period of time with a resolution of 1 millisecond.

Time Second 16

00002B16-0000-1000-8000-00805F9B34FB

The Time Second 16 characteristic is used to represent a period of time with a unit of 1 second.

Time Second 32

00002BE6-0000-1000-8000-00805F9B34FB

The Time Second 32 characteristic is used to represent a period of time with a unit of 1 second.

Time Second 8

00002B17-0000-1000-8000-00805F9B34FB

The Time Second 8 characteristic is used to represent a period of time with a unit of 1 second.

Time Source

00002A13-0000-1000-8000-00805F9B34FB

The Time Source characteristic is used to represent the type of time source that is used for reference time.

Time Zone

00002A0E-0000-1000-8000-00805F9B34FB

The Time Zone characteristic is used to represent the time difference in 15-minute increments between local standard time and UTC.

Time with DST

00002A11-0000-1000-8000-00805F9B34FB

The Time with DST characteristic is used to represent information about a DST change event.

Torque

00002C0B-0000-1000-8000-00805F9B34FB

The Torque characteristic is used to represent the measured magnitude of torque (or moment of force) around a device-specific axis.

UV Index

00002A76-0000-1000-8000-00805F9B34FB

The UV Index characteristic is used to represent the UV Index.

User Index

00002A9A-0000-1000-8000-00805F9B34FB

The User Index characteristic is used to represent the index of a user.

VO2 Max

00002A96-0000-1000-8000-00805F9B34FB

The VO2 Max characteristic is used to represent the maximal oxygen uptake of a user.

VOC Concentration

00002BE7-0000-1000-8000-00805F9B34FB

The VOC Concentration characteristic is used to represent a measure of volatile organic compounds concentration.

Voltage Frequency

00002BE8-0000-1000-8000-00805F9B34FB

The Voltage Frequency characteristic is used to represent power supply voltage frequency.

Voltage Specification

00002B19-0000-1000-8000-00805F9B34FB

The Voltage Specification characteristic is used to represent a specification of voltage values.

Voltage Statistics

00002B1A-0000-1000-8000-00805F9B34FB

The Voltage Statistics characteristic is used to represent a set of statistical voltage values over a period of time.

Volume Flow

00002B1B-0000-1000-8000-00805F9B34FB

The Volume Flow characteristic is used to represent a flow of a general volume such as a volume of material or gas.

Services

The library currently supports 31 GATT services:

Service

UUID

Description

Alert Notification

00001811-0000-1000-8000-00805F9B34FB

Alert Notification Service implementation.

Automation IO

00001815-0000-1000-8000-00805F9B34FB

Automation IO Service implementation.

Battery

0000180F-0000-1000-8000-00805F9B34FB

Battery Service implementation.

Blood Pressure

00001810-0000-1000-8000-00805F9B34FB

Blood Pressure Service implementation.

Body Composition

0000181B-0000-1000-8000-00805F9B34FB

Body Composition Service implementation (0x181B).

Bond Management

0000181E-0000-1000-8000-00805F9B34FB

Bond Management Service implementation.

Current Time

00001805-0000-1000-8000-00805F9B34FB

Current Time Service implementation.

Cycling Power

00001818-0000-1000-8000-00805F9B34FB

Cycling Power Service implementation (0x1818).

Cycling Speed and Cadence

00001816-0000-1000-8000-00805F9B34FB

Cycling Speed and Cadence Service implementation (0x1816).

Device Information

0000180A-0000-1000-8000-00805F9B34FB

Device Information Service implementation.

Environmental Sensing

0000181A-0000-1000-8000-00805F9B34FB

Environmental Sensing Service implementation (0x181A).

Fitness Machine

00001826-0000-1000-8000-00805F9B34FB

Fitness Machine Service implementation.

GAP

00001800-0000-1000-8000-00805F9B34FB

Generic Access Service implementation.

GATT

00001801-0000-1000-8000-00805F9B34FB

Generic Attribute Service implementation.

Glucose

00001808-0000-1000-8000-00805F9B34FB

Glucose Service implementation (0x1808).

Health Thermometer

00001809-0000-1000-8000-00805F9B34FB

Health Thermometer Service implementation (0x1809).

Heart Rate

0000180D-0000-1000-8000-00805F9B34FB

Heart Rate Service implementation (0x180D).

Human Interface Device

00001812-0000-1000-8000-00805F9B34FB

Human Interface Device Service implementation.

Immediate Alert

00001802-0000-1000-8000-00805F9B34FB

Immediate Alert Service implementation.

Indoor Positioning

00001821-0000-1000-8000-00805F9B34FB

Indoor Positioning Service implementation.

Link Loss

00001803-0000-1000-8000-00805F9B34FB

Link Loss Service implementation.

Location and Navigation

00001819-0000-1000-8000-00805F9B34FB

Location and Navigation Service implementation.

Next DST Change

00001807-0000-1000-8000-00805F9B34FB

Next DST Change Service implementation.

Phone Alert Status

0000180E-0000-1000-8000-00805F9B34FB

Phone Alert Status Service implementation.

Pulse Oximeter

00001822-0000-1000-8000-00805F9B34FB

Pulse Oximeter Service implementation.

Reference Time Update

00001806-0000-1000-8000-00805F9B34FB

Reference Time Update Service implementation.

Running Speed and Cadence

00001814-0000-1000-8000-00805F9B34FB

Running Speed and Cadence Service implementation (0x1814).

Scan Parameters

00001813-0000-1000-8000-00805F9B34FB

Scan Parameters service implementation.

Tx Power

00001804-0000-1000-8000-00805F9B34FB

Tx Power Service implementation.

User Data

0000181C-0000-1000-8000-00805F9B34FB

User Data Service implementation.

Weight Scale

0000181D-0000-1000-8000-00805F9B34FB

Weight Scale Service implementation (0x181D).

Adding Support for New Characteristics

To add support for a new characteristic:

  1. See the Adding Characteristics guide

  2. Follow the existing patterns in src/bluetooth_sig/gatt/characteristics/

  3. Add tests for your new characteristic in tests/gatt/characteristics/

  4. Submit a pull request

Official Bluetooth SIG Registry

This library is based on the official Bluetooth SIG Assigned Numbers registry. The UUID registry is loaded from YAML files in the bluetooth_sig submodule.